/* wizard.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from wizard.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <libxml/uri.h>
#include <osinfo/osinfo.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;
typedef struct _BoxesWizardPrivate BoxesWizardPrivate;

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;

#define BOXES_WIZARD_TYPE_WIZARD_SUMMARY (boxes_wizard_wizard_summary_get_type ())
#define BOXES_WIZARD_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummary))
#define BOXES_WIZARD_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummaryClass))
#define BOXES_WIZARD_IS_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_WIZARD_TYPE_WIZARD_SUMMARY))
#define BOXES_WIZARD_IS_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_WIZARD_TYPE_WIZARD_SUMMARY))
#define BOXES_WIZARD_WIZARD_SUMMARY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummaryClass))

typedef struct _BoxesWizardWizardSummary BoxesWizardWizardSummary;
typedef struct _BoxesWizardWizardSummaryClass BoxesWizardWizardSummaryClass;

#define BOXES_TYPE_COLLECTION_SOURCE (boxes_collection_source_get_type ())
#define BOXES_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSource))
#define BOXES_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))
#define BOXES_IS_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_IS_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_COLLECTION_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))

typedef struct _BoxesCollectionSource BoxesCollectionSource;
typedef struct _BoxesCollectionSourceClass BoxesCollectionSourceClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))

#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_ICONFIG (boxes_iconfig_get_type ())
#define BOXES_ICONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICONFIG, BoxesIConfig))
#define BOXES_IS_ICONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICONFIG))
#define BOXES_ICONFIG_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_ICONFIG, BoxesIConfigIface))

typedef struct _BoxesIConfig BoxesIConfig;
typedef struct _BoxesIConfigIface BoxesIConfigIface;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_PAIR (boxes_pair_get_type ())
#define BOXES_PAIR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PAIR, BoxesPair))
#define BOXES_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PAIR, BoxesPairClass))
#define BOXES_IS_PAIR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PAIR))
#define BOXES_IS_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PAIR))
#define BOXES_PAIR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PAIR, BoxesPairClass))

typedef struct _BoxesPair BoxesPair;
typedef struct _BoxesPairClass BoxesPairClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_QUERY (boxes_query_get_type ())
#define BOXES_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_QUERY, BoxesQuery))
#define BOXES_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_QUERY, BoxesQueryClass))
#define BOXES_IS_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_QUERY))
#define BOXES_IS_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_QUERY))
#define BOXES_QUERY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_QUERY, BoxesQueryClass))

typedef struct _BoxesQuery BoxesQuery;
typedef struct _BoxesQueryClass BoxesQueryClass;
typedef struct _BoxesPairPrivate BoxesPairPrivate;
#define _boxes_pair_unref0(var) ((var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL)))
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_TYPE_MACHINE_ACTOR (boxes_machine_actor_get_type ())
#define BOXES_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor))
#define BOXES_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))
#define BOXES_IS_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_IS_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_MACHINE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))

typedef struct _BoxesMachineActor BoxesMachineActor;
typedef struct _BoxesMachineActorClass BoxesMachineActorClass;

#define BOXES_TYPE_DISPLAY_CONFIG (boxes_display_config_get_type ())
#define BOXES_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfig))
#define BOXES_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))
#define BOXES_IS_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_IS_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_DISPLAY_CONFIG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))

typedef struct _BoxesDisplayConfig BoxesDisplayConfig;
typedef struct _BoxesDisplayConfigClass BoxesDisplayConfigClass;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
typedef struct _BoxesWizardReviewData BoxesWizardReviewData;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_SIDEBAR_PAGE (boxes_sidebar_page_get_type ())
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())
typedef struct _BoxesWizardWizardSummaryPrivate BoxesWizardWizardSummaryPrivate;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

typedef enum  {
	BOXES_WIZARD_PAGE_INTRODUCTION,
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesWizard {
	BoxesUI parent_instance;
	BoxesWizardPrivate * priv;
};

struct _BoxesWizardClass {
	BoxesUIClass parent_class;
};

struct _BoxesWizardPrivate {
	GtkClutterActor* gtk_actor;
	GPtrArray* steps;
	GtkNotebook* notebook;
	GtkButton* cancel_button;
	GtkButton* back_button;
	GtkButton* next_button;
	BoxesWizardSource* wizard_source;
	BoxesWizardWizardSummary* summary;
	BoxesCollectionSource* source;
	GtkProgressBar* prep_progress;
	GtkVBox* setup_vbox;
	GtkLabel* review_label;
	GtkLabel* nokvm_label;
	GtkImage* installer_image;
	BoxesMediaManager* media_manager;
	BoxesVMCreator* vm_creator;
	BoxesLibvirtMachine* machine;
	BoxesWizardPage _page;
	gboolean skip_review_for_live;
};

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

struct _BoxesWizardSource {
	GObject parent_instance;
	BoxesWizardSourcePrivate * priv;
	GtkEntry* url_entry;
};

struct _BoxesWizardSourceClass {
	GObjectClass parent_class;
};

struct _BoxesIConfigIface {
	GTypeInterface parent_iface;
	GKeyFile* (*get_keyfile) (BoxesIConfig* self);
	const gchar* (*get_filename) (BoxesIConfig* self);
	void (*set_filename) (BoxesIConfig* self, const gchar* value);
	gboolean (*get_has_file) (BoxesIConfig* self);
	void (*set_has_file) (BoxesIConfig* self, gboolean value);
};

typedef enum  {
	BOXES_ERROR_INVALID,
	BOXES_ERROR_COMMAND_FAILED
} BoxesError;
#define BOXES_ERROR boxes_error_quark ()
typedef enum  {
	UNATTENDED_INSTALLER_ERROR_SETUP_INCOMPLETE
} UnattendedInstallerError;
#define UNATTENDED_INSTALLER_ERROR unattended_installer_error_quark ()
struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_spice_config) (BoxesInstallerMedia* self, GVirConfigDomainGraphicsSpice* graphics);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkVBox* setup_vbox);
	void (*check_needed_info) (BoxesInstallerMedia* self, GError** error);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* topbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
	GSimpleAction* action_shutdown;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesPair {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesPairPrivate * priv;
	gpointer first;
	gpointer second;
};

struct _BoxesPairClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesPair *self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesMachineActor* machine_actor;
	BoxesCollectionSource* source;
	BoxesDisplayConfig* config;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	gchar* (*get_screenshot_prefix) (BoxesMachine* self);
	void (*connect_display) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	GVirDomain* domain;
	GVirConfigDomain* domain_config;
	GVirConnection* connection;
	BoxesVMCreator* vm_creator;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesWizardReviewData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	GtkLabel* _tmp0_;
	BoxesWizardWizardSummary* _tmp1_;
	BoxesVMCreator* _tmp2_;
	BoxesVMCreator* _tmp3_;
	BoxesInstallerMedia* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesVMCreator* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	GError* cancel_error;
	GError* _error_;
	BoxesApp* _tmp9_;
	BoxesNotificationbar* _tmp10_;
	const gchar* _tmp11_;
	GError* _tmp12_;
	const gchar* _tmp13_;
	GtkLabel* _tmp14_;
	const gchar* _tmp15_;
	BoxesCollectionSource* _tmp16_;
	BoxesCollectionSource* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	xmlURI* _tmp21_;
	xmlURI* _tmp22_;
	xmlURI* uri;
	BoxesWizardWizardSummary* _tmp23_;
	const gchar* _tmp24_;
	BoxesCollectionSource* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gboolean _tmp29_;
	xmlURI* _tmp30_;
	xmlURI* _tmp31_;
	const gchar* _tmp32_;
	gboolean _tmp33_;
	BoxesWizardWizardSummary* _tmp34_;
	const gchar* _tmp35_;
	xmlURI* _tmp36_;
	const gchar* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	BoxesWizardWizardSummary* _tmp40_;
	const gchar* _tmp41_;
	BoxesCollectionSource* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
	xmlURI* _tmp48_;
	const gchar* _tmp49_;
	const gchar* _tmp50_;
	GQuark _tmp52_;
	xmlURI* _tmp53_;
	const gchar* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	const gchar* _tmp57_;
	xmlURI* _tmp58_;
	const gchar* _tmp59_;
	gchar* _tmp60_;
	const gchar* _tmp61_;
	BoxesQuery* _tmp62_;
	BoxesQuery* query;
	BoxesWizardWizardSummary* _tmp63_;
	const gchar* _tmp64_;
	BoxesQuery* _tmp65_;
	gchar* _tmp66_;
	gchar* _tmp67_;
	BoxesWizardWizardSummary* _tmp68_;
	const gchar* _tmp69_;
	BoxesQuery* _tmp70_;
	gchar* _tmp71_;
	gchar* _tmp72_;
	xmlURI* _tmp73_;
	gint _tmp74_;
	BoxesWizardWizardSummary* _tmp75_;
	const gchar* _tmp76_;
	xmlURI* _tmp77_;
	gint _tmp78_;
	gchar* _tmp79_;
	gchar* _tmp80_;
	BoxesCollectionSource* _tmp81_;
	gchar* _tmp82_;
	gchar* _tmp83_;
	gchar* _tmp84_;
	gboolean _tmp85_;
	GtkLabel* _tmp86_;
	const gchar* _tmp87_;
	BoxesVMCreator* _tmp88_;
	BoxesVMCreator* _tmp89_;
	BoxesInstallerMedia* _tmp90_;
	BoxesInstallerMedia* _tmp91_;
	GList* _tmp92_;
	GList* property_collection;
	GList* property_it;
	BoxesPair* _tmp93_;
	BoxesPair* property;
	BoxesWizardWizardSummary* _tmp94_;
	BoxesPair* _tmp95_;
	gconstpointer _tmp96_;
	BoxesPair* _tmp97_;
	gconstpointer _tmp98_;
	BoxesVMCreator* _tmp99_;
	BoxesInstallerMedia* _tmp100_;
	BoxesInstallerMedia* _tmp101_;
	OsinfoResources* _tmp102_;
	gint64 _tmp103_;
	gint64 _tmp104_;
	gchar* _tmp105_;
	gchar* memory;
	BoxesWizardWizardSummary* _tmp106_;
	const gchar* _tmp107_;
	const gchar* _tmp108_;
	BoxesVMCreator* _tmp109_;
	BoxesInstallerMedia* _tmp110_;
	BoxesInstallerMedia* _tmp111_;
	OsinfoResources* _tmp112_;
	gint64 _tmp113_;
	gint64 _tmp114_;
	gchar* _tmp115_;
	BoxesWizardWizardSummary* _tmp116_;
	const gchar* _tmp117_;
	const gchar* _tmp118_;
	gchar* _tmp119_;
	gchar* _tmp120_;
	const gchar* _tmp121_;
	GtkLabel* _tmp122_;
	BoxesLibvirtMachine* _tmp123_;
	GVirConfigDomain* _tmp124_;
	GVirConfigDomainVirtType _tmp125_;
	GError * _inner_error_;
};

struct _BoxesSidebar {
	BoxesUI parent_instance;
	BoxesSidebarPrivate * priv;
	GtkNotebook* notebook;
};

struct _BoxesSidebarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_SIDEBAR_PAGE_COLLECTION,
	BOXES_SIDEBAR_PAGE_WIZARD,
	BOXES_SIDEBAR_PAGE_PROPERTIES
} BoxesSidebarPage;

struct _BoxesTopbar {
	BoxesUI parent_instance;
	BoxesTopbarPrivate * priv;
	GtkLabel* label;
	GtkNotebook* notebook;
};

struct _BoxesTopbarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES
} BoxesTopbarPage;

struct _BoxesWizardWizardSummary {
	GObject parent_instance;
	BoxesWizardWizardSummaryPrivate * priv;
};

struct _BoxesWizardWizardSummaryClass {
	GObjectClass parent_class;
};

struct _BoxesWizardWizardSummaryPrivate {
	GtkTable* table;
	guint current_row;
};


static gpointer boxes_wizard_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_wizard_wizard_summary_parent_class = NULL;

GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
static GType boxes_wizard_wizard_summary_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType boxes_collection_source_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD, BoxesWizardPrivate))
enum  {
	BOXES_WIZARD_DUMMY_PROPERTY,
	BOXES_WIZARD_ACTOR
};
static void boxes_wizard_wizard_source_update_next (BoxesWizard* self);
GType boxes_source_page_get_type (void) G_GNUC_CONST;
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, GError** error);
gchar* boxes_collection_source_get_source_type (BoxesCollectionSource* self);
void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name);
BoxesWizard* boxes_wizard_new (void);
BoxesWizard* boxes_wizard_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
BoxesWizardSource* boxes_wizard_source_new (BoxesMediaManager* media_manager);
BoxesWizardSource* boxes_wizard_source_construct (GType object_type, BoxesMediaManager* media_manager);
static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void __lambda113_ (BoxesWizard* self);
static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value);
static void ___lambda113__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_wizard_setup_ui (BoxesWizard* self);
void boxes_wizard_cleanup (BoxesWizard* self);
static void boxes_wizard_destroy_machine (BoxesWizard* self);
static gboolean boxes_wizard_create (BoxesWizard* self);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
GType boxes_iconfig_get_type (void) G_GNUC_CONST;
void boxes_iconfig_save (BoxesIConfig* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_);
GQuark boxes_error_quark (void);
static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, GError** error);
static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error);
BoxesCollectionSource* boxes_collection_source_new (const gchar* name, const gchar* source_type, const gchar* uri);
BoxesCollectionSource* boxes_collection_source_construct (GType object_type, const gchar* name, const gchar* source_type, const gchar* uri);
void boxes_collection_source_set_source_type (BoxesCollectionSource* self, const gchar* value);
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GObject* source_object, GAsyncResult* _result_);
static void _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size);
GQuark unattended_installer_error_quark (void);
gpointer boxes_pair_ref (gpointer instance);
void boxes_pair_unref (gpointer instance);
GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_pair (GValue* value, gpointer v_object);
void boxes_value_take_pair (GValue* value, gpointer v_object);
gpointer boxes_value_get_pair (const GValue* value);
GType boxes_pair_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
void boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message);
static gboolean boxes_wizard_prepare (BoxesWizard* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
static gboolean boxes_wizard_setup (BoxesWizard* self);
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_populate_setup_vbox (BoxesInstallerMedia* self, GtkVBox* setup_vbox);
static void boxes_wizard_review_data_free (gpointer _data);
static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_);
static void boxes_wizard_wizard_summary_clear (BoxesWizardWizardSummary* self);
void boxes_installer_media_check_needed_info (BoxesInstallerMedia* self, GError** error);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gchar* boxes_collection_source_get_uri (BoxesCollectionSource* self);
static void boxes_wizard_wizard_summary_add_property (BoxesWizardWizardSummary* self, const gchar* name, const gchar* value);
BoxesQuery* boxes_query_new (const gchar* query);
BoxesQuery* boxes_query_construct (GType object_type, const gchar* query);
GType boxes_query_get_type (void) G_GNUC_CONST;
gchar* boxes_query_get (BoxesQuery* self, const gchar* key);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_actor_get_type (void) G_GNUC_CONST;
GType boxes_display_config_get_type (void) G_GNUC_CONST;
static void boxes_wizard_add_step (BoxesWizard* self, GtkWidget* widget, const gchar* title, BoxesWizardPage page);
GType boxes_sidebar_page_get_type (void) G_GNUC_CONST;
static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page);
static BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
gchar* boxes_get_pixmap (const gchar* file_name);
GtkWidget* boxes_wizard_source_get_widget (BoxesWizardSource* self);
static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_new (void);
static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_construct (GType object_type);
static GtkWidget* boxes_wizard_wizard_summary_get_widget (BoxesWizardWizardSummary* self);
GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
static void __lambda114_ (BoxesWizard* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda114__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda115_ (BoxesWizard* self);
static void ___lambda115__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda116_ (BoxesWizard* self);
static void ___lambda116__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
static void boxes_wizard_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value);
static void _boxes_wizard_page_____lambda109_ (BoxesWizard* self, GObject* source, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda109__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_get_color (const gchar* desc, GdkColor* result);
static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _g_object_unref0_ (gpointer var);
BoxesMediaManager* boxes_media_manager_new (void);
BoxesMediaManager* boxes_media_manager_construct (GType object_type);
#define BOXES_WIZARD_WIZARD_SUMMARY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummaryPrivate))
enum  {
	BOXES_WIZARD_WIZARD_SUMMARY_DUMMY_PROPERTY,
	BOXES_WIZARD_WIZARD_SUMMARY_WIDGET
};
static void boxes_wizard_wizard_summary_finalize (GObject* obj);
static void _vala_boxes_wizard_wizard_summary_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void boxes_wizard_finalize (GObject* obj);
static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_wizard_page_get_type (void) {
	static volatile gsize boxes_wizard_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_WIZARD_PAGE_INTRODUCTION, "BOXES_WIZARD_PAGE_INTRODUCTION", "introduction"}, {BOXES_WIZARD_PAGE_SOURCE, "BOXES_WIZARD_PAGE_SOURCE", "source"}, {BOXES_WIZARD_PAGE_PREPARATION, "BOXES_WIZARD_PAGE_PREPARATION", "preparation"}, {BOXES_WIZARD_PAGE_SETUP, "BOXES_WIZARD_PAGE_SETUP", "setup"}, {BOXES_WIZARD_PAGE_REVIEW, "BOXES_WIZARD_PAGE_REVIEW", "review"}, {BOXES_WIZARD_PAGE_LAST, "BOXES_WIZARD_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_wizard_page_type_id;
		boxes_wizard_page_type_id = g_enum_register_static ("BoxesWizardPage", values);
		g_once_init_leave (&boxes_wizard_page_type_id__volatile, boxes_wizard_page_type_id);
	}
	return boxes_wizard_page_type_id__volatile;
}


static void boxes_wizard_wizard_source_update_next (BoxesWizard* self) {
	GtkButton* _tmp0_;
	BoxesWizardSource* _tmp1_;
	BoxesSourcePage _tmp2_;
	BoxesSourcePage _tmp3_;
	GError * _inner_error_ = NULL;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_wizard_source_get_page (_tmp1_);
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	switch (_tmp3_) {
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 932 "wizard.c"
		{
			GtkButton* _tmp4_;
			BoxesWizardSource* _tmp5_;
			GtkWidget* _tmp6_;
			GtkWidget* _tmp7_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp4_ = self->priv->next_button;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp5_ = self->priv->wizard_source;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp6_ = boxes_wizard_source_get_selected (_tmp5_);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp7_ = _tmp6_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp4_, _tmp7_ != NULL);
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 950 "wizard.c"
		}
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 954 "wizard.c"
		{
			GtkButton* _tmp8_;
			BoxesWizardSource* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			const gchar* _tmp14_ = NULL;
			gchar* _tmp15_;
			gchar* text;
			gchar* _tmp16_;
			gchar* icon;
			BoxesWizardSource* _tmp32_;
			const gchar* _tmp33_ = NULL;
			const gchar* _tmp34_;
			const gchar* _tmp35_;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp8_ = self->priv->next_button;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp9_ = self->priv->wizard_source;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp10_ = boxes_wizard_source_get_uri (_tmp9_);
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp11_ = _tmp10_;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp12_ = strlen (_tmp11_);
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, _tmp13_ != 0);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp14_ = _ ("Please enter desktop or collection URI");
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp15_ = g_strdup (_tmp14_);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			text = _tmp15_;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp16_ = g_strdup ("preferences-desktop-remote-desktop");
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			icon = _tmp16_;
#line 995 "wizard.c"
			{
				BoxesWizardSource* _tmp17_;
				const gchar* _tmp18_;
				const gchar* _tmp19_;
				gboolean _tmp20_ = FALSE;
				BoxesCollectionSource* _tmp21_;
				gboolean _tmp26_;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp17_ = self->priv->wizard_source;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp18_ = boxes_wizard_source_get_uri (_tmp17_);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp19_ = _tmp18_;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				boxes_wizard_prepare_for_location (self, _tmp19_, TRUE, &_inner_error_);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (_inner_error_ != NULL) {
#line 1013 "wizard.c"
					goto __catch75_g_error;
				}
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp21_ = self->priv->source;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (_tmp21_ != NULL) {
#line 1020 "wizard.c"
					BoxesCollectionSource* _tmp22_;
					gchar* _tmp23_;
					gchar* _tmp24_;
					gchar* _tmp25_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp22_ = self->priv->source;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp23_ = boxes_collection_source_get_source_type (_tmp22_);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp24_ = _tmp23_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp25_ = _tmp24_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp20_ = g_strcmp0 (_tmp25_, "libvirt") == 0;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp25_);
#line 1037 "wizard.c"
				} else {
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp20_ = FALSE;
#line 1041 "wizard.c"
				}
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp26_ = _tmp20_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (_tmp26_) {
#line 1047 "wizard.c"
					const gchar* _tmp27_ = NULL;
					gchar* _tmp28_;
					gchar* _tmp29_;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp27_ = _ ("Will add boxes for all systems available from this account.");
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp28_ = g_strdup (_tmp27_);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					text = _tmp28_;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp29_ = g_strdup ("network-workgroup");
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_free0 (icon);
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					icon = _tmp29_;
#line 1065 "wizard.c"
				} else {
					const gchar* _tmp30_ = NULL;
					gchar* _tmp31_;
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp30_ = _ ("Will add a single box.");
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp31_ = g_strdup (_tmp30_);
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					text = _tmp31_;
#line 1077 "wizard.c"
				}
			}
			goto __finally75;
			__catch75_g_error:
			{
				GError* _error_ = NULL;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_error_ = _inner_error_;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_inner_error_ = NULL;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_error_);
#line 1090 "wizard.c"
			}
			__finally75:
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_free0 (icon);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_free0 (text);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				return;
#line 1105 "wizard.c"
			}
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp32_ = self->priv->wizard_source;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp33_ = _ ("Desktop Access");
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp34_ = text;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp35_ = icon;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_update_url_page (_tmp32_, _tmp33_, _tmp34_, _tmp35_);
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (icon);
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (text);
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 1123 "wizard.c"
		}
		default:
		{
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_warn_if_reached ();
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 1131 "wizard.c"
		}
	}
}


static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next (self);
#line 1140 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next (self);
#line 1147 "wizard.c"
}


static void __lambda113_ (BoxesWizard* self) {
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 1154 "wizard.c"
}


static void ___lambda113__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	__lambda113_ (self);
#line 1161 "wizard.c"
}


BoxesWizard* boxes_wizard_construct (GType object_type) {
	BoxesWizard * self = NULL;
	BoxesMediaManager* _tmp0_;
	BoxesWizardSource* _tmp1_;
	BoxesWizardSource* _tmp2_;
	BoxesWizardSource* _tmp3_;
	BoxesWizardSource* _tmp4_;
	GtkEntry* _tmp5_;
	BoxesWizardSource* _tmp6_;
	GtkEntry* _tmp7_;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) boxes_ui_construct (object_type);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->media_manager;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_source_new (_tmp0_);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->wizard_source);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->wizard_source = _tmp1_;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp2_, "notify::page", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::selected", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->wizard_source;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = _tmp4_->url_entry;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GtkEditable*) _tmp5_, "changed", (GCallback) _boxes_wizard_wizard_source_update_next_gtk_editable_changed, self, 0);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->wizard_source;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_->url_entry;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp7_, "activate", (GCallback) ___lambda113__gtk_entry_activate, self, 0);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_setup_ui (self);
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return self;
#line 1209 "wizard.c"
}


BoxesWizard* boxes_wizard_new (void) {
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return boxes_wizard_construct (BOXES_TYPE_WIZARD);
#line 1216 "wizard.c"
}


void boxes_wizard_cleanup (BoxesWizard* self) {
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_destroy_machine (self);
#line 1225 "wizard.c"
}


static gboolean boxes_wizard_create (BoxesWizard* self) {
	gboolean result = FALSE;
	BoxesCollectionSource* _tmp0_;
	BoxesCollectionSource* _tmp8_;
	BoxesApp* _tmp9_;
	BoxesCollectionSource* _tmp10_;
	GError * _inner_error_ = NULL;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->source;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp0_ == NULL) {
#line 1242 "wizard.c"
		BoxesVMCreator* _tmp1_;
		GtkButton* _tmp2_;
		BoxesWizardSource* _tmp7_;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->vm_creator;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_return_val_if_fail (_tmp1_ != NULL, FALSE);
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->next_button;
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 1254 "wizard.c"
		{
			BoxesVMCreator* _tmp3_;
			BoxesLibvirtMachine* _tmp4_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp3_ = self->priv->vm_creator;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp4_ = self->priv->machine;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_vm_creator_launch_vm (_tmp3_, _tmp4_, &_inner_error_);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 1266 "wizard.c"
				goto __catch76_g_error;
			}
		}
		goto __finally76;
		__catch76_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp5_;
			const gchar* _tmp6_;
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_error_ = _inner_error_;
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_inner_error_ = NULL;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp5_ = _error_;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp6_ = _tmp5_->message;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:187: %s", _tmp6_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			result = FALSE;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_error_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return result;
#line 1292 "wizard.c"
		}
		__finally76:
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_inner_error_ != NULL) {
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1303 "wizard.c"
		}
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		self->priv->vm_creator = NULL;
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self->priv->machine);
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		self->priv->machine = NULL;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp7_ = self->priv->wizard_source;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_wizard_source_set_uri (_tmp7_, "");
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return result;
#line 1321 "wizard.c"
	}
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->source;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_iconfig_save ((BoxesIConfig*) _tmp8_);
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp9_ = boxes_app_app;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp10_ = self->priv->source;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_app_add_collection_source (_tmp9_, _tmp10_, NULL, NULL);
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return result;
#line 1337 "wizard.c"
}


static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, GError** error) {
	const gchar* _tmp0_;
	const gchar* _tmp2_;
	GFile* _tmp3_ = NULL;
	GFile* file;
	GFile* _tmp4_;
	gboolean _tmp5_ = FALSE;
	GError * _inner_error_ = NULL;
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (location != NULL);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->source = NULL;
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = location;
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp0_, "") == 0) {
#line 1361 "wizard.c"
		GError* _tmp1_;
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp1_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "empty location");
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp1_;
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return;
#line 1371 "wizard.c"
	}
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = location;
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = g_file_new_for_commandline_arg (_tmp2_);
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	file = _tmp3_;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = file;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = g_file_is_native (_tmp4_);
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp5_) {
#line 1385 "wizard.c"
		gboolean _tmp6_;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp6_ = probing;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (!_tmp6_) {
#line 1391 "wizard.c"
			GFile* _tmp7_;
			gchar* _tmp8_ = NULL;
			gchar* _tmp9_;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp7_ = file;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp8_ = g_file_get_path (_tmp7_);
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp8_;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_installer (self, _tmp9_, &_inner_error_);
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_tmp9_);
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				return;
#line 1413 "wizard.c"
			}
		}
	} else {
		gboolean uncertain = FALSE;
		GFile* _tmp10_;
		gchar* _tmp11_ = NULL;
		gchar* uri;
		const gchar* _tmp12_;
		gboolean _tmp13_ = FALSE;
		gchar* _tmp14_ = NULL;
		gchar* mimetype;
		gboolean _tmp15_;
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp10_ = file;
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp11_ = g_file_get_uri (_tmp10_);
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		uri = _tmp11_;
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp12_ = uri;
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp14_ = g_content_type_guess (_tmp12_, NULL, 0, &_tmp13_);
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		uncertain = _tmp13_;
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		mimetype = _tmp14_;
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp15_ = uncertain;
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_tmp15_) {
#line 1444 "wizard.c"
			const gchar* _tmp16_;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp16_ = uri;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_uri (self, _tmp16_, &_inner_error_);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_free0 (mimetype);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_free0 (uri);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				return;
#line 1462 "wizard.c"
			}
		} else {
			const gchar* _tmp17_;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp17_ = mimetype;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp18_ = g_strdup_printf ("FIXME: %s", _tmp17_);
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp19_ = _tmp18_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_debug ("wizard.vala:225: %s", _tmp19_);
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_tmp19_);
#line 1478 "wizard.c"
		}
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_free0 (mimetype);
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_free0 (uri);
#line 1484 "wizard.c"
	}
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (file);
#line 1488 "wizard.c"
}


static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error) {
	const gchar* _tmp0_;
	xmlURI* _tmp1_ = NULL;
	xmlURI* uri;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	BoxesCollectionSource* _tmp13_;
	gboolean _tmp14_ = FALSE;
	const gchar* _tmp15_;
	gboolean _tmp17_;
	GError * _inner_error_ = NULL;
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = uri_as_text;
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	uri = _tmp1_;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (uri == NULL) {
#line 1520 "wizard.c"
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp2_ = _ ("Invalid URI");
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp3_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp2_);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp3_;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_propagate_error (error, _inner_error_);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return;
#line 1537 "wizard.c"
		} else {
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return;
#line 1547 "wizard.c"
		}
	}
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = uri->server;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp6_ = _tmp5_;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp7_ == NULL) {
#line 1560 "wizard.c"
		const gchar* _tmp8_;
		gchar* _tmp9_;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp8_ = uri_as_text;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_free0 (_tmp6_);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp9_;
#line 1571 "wizard.c"
	}
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp10_ = _tmp6_;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp11_ = uri->scheme;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp12_ = uri_as_text;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp13_ = boxes_collection_source_new (_tmp10_, _tmp11_, _tmp12_);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->source = _tmp13_;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp15_ = uri->scheme;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp15_, "spice") == 0) {
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp14_ = TRUE;
#line 1591 "wizard.c"
	} else {
		const gchar* _tmp16_;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp16_ = uri->scheme;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp14_ = g_strcmp0 (_tmp16_, "vnc") == 0;
#line 1598 "wizard.c"
	}
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp17_ = _tmp14_;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp17_) {
#line 1604 "wizard.c"
	} else {
		const gchar* _tmp18_;
		gboolean _tmp19_ = FALSE;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp18_ = uri->scheme;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp19_ = g_str_has_prefix (_tmp18_, "qemu");
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_tmp19_) {
#line 1614 "wizard.c"
			BoxesCollectionSource* _tmp20_;
#line 242 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp20_ = self->priv->source;
#line 242 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_collection_source_set_source_type (_tmp20_, "libvirt");
#line 1620 "wizard.c"
		} else {
			const gchar* _tmp21_ = NULL;
			const gchar* _tmp22_;
			gchar* _tmp23_ = NULL;
			gchar* _tmp24_;
			GError* _tmp25_;
			GError* _tmp26_;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp21_ = _ ("Unsupported protocol '%s'");
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp22_ = uri->scheme;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp23_ = g_strdup_printf (_tmp21_, _tmp22_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp24_ = _tmp23_;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp25_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp24_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp26_ = _tmp25_;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_tmp24_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_inner_error_ = _tmp26_;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_free0 (_tmp6_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				return;
#line 1654 "wizard.c"
			} else {
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_free0 (_tmp6_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				return;
#line 1666 "wizard.c"
			}
		}
	}
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp6_);
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_xmlFreeURI0 (uri);
#line 1674 "wizard.c"
}


static void _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_on_installer_media_instantiated (self, source_object, res);
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 1683 "wizard.c"
}


static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, GError** error) {
	GtkButton* _tmp0_;
	BoxesMediaManager* _tmp1_;
	const gchar* _tmp2_;
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (path != NULL);
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->media_manager;
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = path;
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_media_manager_create_installer_media_for_path (_tmp1_, _tmp2_, NULL, _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback, g_object_ref (self));
#line 1705 "wizard.c"
}


static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GObject* source_object, GAsyncResult* _result_) {
	GtkButton* _tmp0_;
	GError * _inner_error_ = NULL;
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, TRUE);
#line 1720 "wizard.c"
	{
		BoxesMediaManager* _tmp1_;
		GAsyncResult* _tmp2_;
		BoxesInstallerMedia* _tmp3_ = NULL;
		BoxesInstallerMedia* install_media;
		BoxesInstallerMedia* _tmp4_;
		BoxesVMCreator* _tmp5_;
		GtkImage* _tmp6_;
		BoxesInstallerMedia* _tmp7_;
		OsinfoOs* _tmp8_;
		GtkProgressBar* _tmp9_;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->media_manager;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp2_ = _result_;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_media_manager_create_installer_media_for_path_finish (_tmp1_, _tmp2_, &_inner_error_);
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		install_media = _tmp3_;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_inner_error_ != NULL) {
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 1744 "wizard.c"
				goto __catch77_g_io_error_cancelled;
			}
			goto __catch77_g_error;
		}
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp4_ = install_media;
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_vm_creator_new (_tmp4_);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		self->priv->vm_creator = _tmp5_;
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp6_ = self->priv->installer_image;
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp7_ = install_media;
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp8_ = _tmp7_->os;
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_fetch_os_logo (_tmp6_, _tmp8_, 128);
#line 259 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp9_ = self->priv->prep_progress;
#line 259 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		gtk_progress_bar_set_fraction (_tmp9_, 1.0);
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SETUP);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (install_media);
#line 1773 "wizard.c"
	}
	goto __finally77;
	__catch77_g_io_error_cancelled:
	{
		GError* cancel_error = NULL;
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		cancel_error = _inner_error_;
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_error_free0 (cancel_error);
#line 1785 "wizard.c"
	}
	goto __finally77;
	__catch77_g_error:
	{
		GError* _error_ = NULL;
		BoxesApp* _tmp10_;
		BoxesNotificationbar* _tmp11_;
		GError* _tmp12_;
		const gchar* _tmp13_;
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp10_ = boxes_app_app;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp11_ = _tmp10_->notificationbar;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp12_ = _error_;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp13_ = _tmp12_->message;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_notificationbar_display_error (_tmp11_, _tmp13_);
#line 264 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 1813 "wizard.c"
	}
	__finally77:
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_inner_error_ != NULL) {
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return;
#line 1824 "wizard.c"
	}
}


static gboolean boxes_wizard_prepare (BoxesWizard* self) {
	gboolean result = FALSE;
	GtkImage* _tmp0_;
	BoxesWizardSource* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	GError * _inner_error_ = NULL;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->installer_image;
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_image_set_from_icon_name (_tmp0_, "media-optical", 0);
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_wizard_source_get_install_media (_tmp1_);
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp3_ != NULL) {
#line 1850 "wizard.c"
		BoxesWizardSource* _tmp4_;
		BoxesInstallerMedia* _tmp5_;
		BoxesInstallerMedia* _tmp6_;
		BoxesVMCreator* _tmp7_;
		GtkProgressBar* _tmp8_;
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->wizard_source;
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_wizard_source_get_install_media (_tmp4_);
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_;
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp7_ = boxes_vm_creator_new (_tmp6_);
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		self->priv->vm_creator = _tmp7_;
#line 273 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp8_ = self->priv->prep_progress;
#line 273 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		gtk_progress_bar_set_fraction (_tmp8_, 1.0);
#line 274 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SETUP);
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		result = FALSE;
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return result;
#line 1878 "wizard.c"
	} else {
		{
			BoxesWizardSource* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp9_ = self->priv->wizard_source;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp10_ = boxes_wizard_source_get_uri (_tmp9_);
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp11_ = _tmp10_;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_location (self, _tmp11_, FALSE, &_inner_error_);
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 1894 "wizard.c"
				goto __catch78_g_error;
			}
		}
		goto __finally78;
		__catch78_g_error:
		{
			GError* _error_ = NULL;
			BoxesApp* _tmp12_;
			BoxesNotificationbar* _tmp13_;
			GError* _tmp14_;
			const gchar* _tmp15_;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_error_ = _inner_error_;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_inner_error_ = NULL;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp12_ = boxes_app_app;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_->notificationbar;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp14_ = _error_;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_->message;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_notificationbar_display_error (_tmp13_, _tmp15_);
#line 282 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			result = FALSE;
#line 282 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_error_);
#line 282 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return result;
#line 1926 "wizard.c"
		}
		__finally78:
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_inner_error_ != NULL) {
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1937 "wizard.c"
		}
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return result;
#line 1943 "wizard.c"
	}
}


static gboolean boxes_wizard_setup (BoxesWizard* self) {
	gboolean result = FALSE;
	BoxesCollectionSource* _tmp0_;
	BoxesVMCreator* _tmp1_;
	BoxesVMCreator* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	BoxesInstallerMedia* _tmp4_;
	GtkVBox* _tmp5_;
#line 289 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->source;
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return result;
#line 1966 "wizard.c"
	}
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->vm_creator;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_tmp1_ != NULL);
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->vm_creator;
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_vm_creator_get_install_media (_tmp2_);
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->setup_vbox;
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_installer_media_populate_setup_vbox (_tmp4_, _tmp5_);
#line 298 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 298 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return result;
#line 1986 "wizard.c"
}


static void boxes_wizard_review_data_free (gpointer _data) {
	BoxesWizardReviewData* _data_;
	_data_ = _data;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardReviewData, _data_);
#line 1997 "wizard.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return self ? g_object_ref (self) : NULL;
#line 2004 "wizard.c"
}


static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
	BoxesWizard* _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardReviewData);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_review);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_review_data_free);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 2023 "wizard.c"
}


static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardReviewData* _data_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return result;
#line 2036 "wizard.c"
}


static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 2050 "wizard.c"
}


static gpointer _boxes_pair_ref0 (gpointer self) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return self ? boxes_pair_ref (self) : NULL;
#line 2057 "wizard.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 2064 "wizard.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_list_free (self);
#line 2073 "wizard.c"
}


static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_) {
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case 0:
#line 2082 "wizard.c"
		goto _state_0;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case 1:
#line 2086 "wizard.c"
		goto _state_1;
		default:
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 2091 "wizard.c"
	}
	_state_0:
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->nokvm_label;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_hide ((GtkWidget*) _data_->_tmp0_);
#line 303 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->self->priv->summary;
#line 303 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_summary_clear (_data_->_tmp1_);
#line 305 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = _data_->self->priv->vm_creator;
#line 305 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp2_ != NULL) {
#line 2106 "wizard.c"
		{
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp3_ = _data_->self->priv->vm_creator;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = boxes_vm_creator_get_install_media (_data_->_tmp3_);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_installer_media_check_needed_info (_data_->_tmp5_, &_data_->_inner_error_);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_data_->_inner_error_ != NULL) {
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 2120 "wizard.c"
					goto __catch79_g_io_error_cancelled;
				}
				goto __catch79_g_error;
			}
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = _data_->self->priv->vm_creator;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_state_ = 1;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_vm_creator_create_vm (_data_->_tmp6_, NULL, boxes_wizard_review_ready, _data_);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 2133 "wizard.c"
			_state_1:
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = NULL;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = boxes_vm_creator_create_vm_finish (_data_->_tmp6_, _data_->_res_, &_data_->_inner_error_);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_data_->_inner_error_ != NULL) {
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 2145 "wizard.c"
					goto __catch79_g_io_error_cancelled;
				}
				goto __catch79_g_error;
			}
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_data_->self->priv->machine);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->self->priv->machine = _data_->_tmp8_;
#line 2154 "wizard.c"
		}
		goto __finally79;
		__catch79_g_io_error_cancelled:
		{
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->cancel_error = _data_->_inner_error_;
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->result = FALSE;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->cancel_error);
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_data_->_state_ == 0) {
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2171 "wizard.c"
			} else {
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2175 "wizard.c"
			}
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 2181 "wizard.c"
		}
		goto __finally79;
		__catch79_g_error:
		{
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = boxes_app_app;
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = _data_->_tmp9_->notificationbar;
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = NULL;
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = _ ("Box setup failed");
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_notificationbar_display_error (_data_->_tmp10_, _data_->_tmp11_);
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_error_;
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = _data_->_tmp12_->message;
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:313: %s", _data_->_tmp13_);
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->result = FALSE;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_data_->_state_ == 0) {
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2214 "wizard.c"
			} else {
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2218 "wizard.c"
			}
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 2224 "wizard.c"
		}
		__finally79:
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_data_->_inner_error_ != NULL) {
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 2235 "wizard.c"
		}
	}
#line 319 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_tmp14_ = _data_->self->priv->review_label;
#line 319 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_tmp15_ = NULL;
#line 319 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_tmp15_ = _ ("Will create a new box with the following properties:");
#line 319 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_text (_data_->_tmp14_, _data_->_tmp15_);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->_tmp16_ = _data_->self->priv->source;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp16_ != NULL) {
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		static GQuark _tmp51_label0 = 0;
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		static GQuark _tmp51_label1 = 0;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = _data_->self->priv->source;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = boxes_collection_source_get_uri (_data_->_tmp17_);
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp19_ = _data_->_tmp18_;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp20_ = _data_->_tmp19_;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp21_ = NULL;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp21_ = xmlParseURI (_data_->_tmp20_);
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp22_ = _data_->_tmp21_;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp20_);
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->uri = _data_->_tmp22_;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp23_ = _data_->self->priv->summary;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp24_ = NULL;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp24_ = _ ("Type");
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp25_ = _data_->self->priv->source;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp26_ = boxes_collection_source_get_source_type (_data_->_tmp25_);
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_wizard_wizard_summary_add_property (_data_->_tmp23_, _data_->_tmp24_, _data_->_tmp28_);
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp28_);
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp30_ = _data_->uri;
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp30_ != NULL) {
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp31_ = _data_->uri;
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp32_ = _data_->_tmp31_->server;
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp29_ = _data_->_tmp32_ != NULL;
#line 2300 "wizard.c"
		} else {
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp29_ = FALSE;
#line 2304 "wizard.c"
		}
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp33_ = _data_->_tmp29_;
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp33_) {
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp34_ = _data_->self->priv->summary;
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp35_ = NULL;
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp35_ = _ ("Host");
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp36_ = _data_->uri;
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp37_ = _data_->_tmp36_->server;
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp38_ = NULL;
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp38_ = g_utf8_strdown (_data_->_tmp37_, (gssize) (-1));
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp39_ = _data_->_tmp38_;
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_wizard_summary_add_property (_data_->_tmp34_, _data_->_tmp35_, _data_->_tmp39_);
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp39_);
#line 2330 "wizard.c"
		} else {
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp40_ = _data_->self->priv->summary;
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp41_ = NULL;
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp41_ = _ ("URI");
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp42_ = _data_->self->priv->source;
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp43_ = boxes_collection_source_get_uri (_data_->_tmp42_);
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp44_ = _data_->_tmp43_;
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp45_ = _data_->_tmp44_;
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = NULL;
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = g_utf8_strdown (_data_->_tmp45_, (gssize) (-1));
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp47_ = _data_->_tmp46_;
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_wizard_summary_add_property (_data_->_tmp40_, _data_->_tmp41_, _data_->_tmp47_);
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp47_);
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp45_);
#line 2358 "wizard.c"
		}
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp48_ = _data_->uri;
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp49_ = _data_->_tmp48_->scheme;
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp52_ = 0U;
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp50_ = _data_->_tmp49_;
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp52_ = (NULL == _data_->_tmp50_) ? 0 : g_quark_from_string (_data_->_tmp50_);
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp52_ == ((0 != _tmp51_label0) ? _tmp51_label0 : (_tmp51_label0 = g_quark_from_static_string ("spice")))) {
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 2374 "wizard.c"
				default:
				{
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp53_ = _data_->uri;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp54_ = _data_->_tmp53_->query_raw;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp55_ = g_strdup (_data_->_tmp54_);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp56_ = _data_->_tmp55_;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp57_ = _data_->_tmp56_;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					if (_data_->_tmp57_ == NULL) {
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp58_ = _data_->uri;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp59_ = _data_->_tmp58_->query;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp60_ = g_strdup (_data_->_tmp59_);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp56_);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp56_ = _data_->_tmp60_;
#line 2399 "wizard.c"
					}
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp61_ = _data_->_tmp56_;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp62_ = boxes_query_new (_data_->_tmp61_);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->query = _data_->_tmp62_;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp63_ = _data_->self->priv->summary;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp64_ = NULL;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp64_ = _ ("Port");
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp65_ = _data_->query;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp66_ = NULL;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp66_ = boxes_query_get (_data_->_tmp65_, "port");
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp67_ = _data_->_tmp66_;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					boxes_wizard_wizard_summary_add_property (_data_->_tmp63_, _data_->_tmp64_, _data_->_tmp67_);
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->_tmp67_);
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp68_ = _data_->self->priv->summary;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp69_ = NULL;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp69_ = _ ("TLS Port");
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp70_ = _data_->query;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp71_ = NULL;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp71_ = boxes_query_get (_data_->_tmp70_, "tls-port");
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp72_ = _data_->_tmp71_;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					boxes_wizard_wizard_summary_add_property (_data_->_tmp68_, _data_->_tmp69_, _data_->_tmp72_);
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->_tmp72_);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_object_unref0 (_data_->query);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->_tmp56_);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					break;
#line 2449 "wizard.c"
				}
			}
		} else if (_data_->_tmp52_ == ((0 != _tmp51_label1) ? _tmp51_label1 : (_tmp51_label1 = g_quark_from_static_string ("vnc")))) {
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 2455 "wizard.c"
				default:
				{
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp73_ = _data_->uri;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp74_ = _data_->_tmp73_->port;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					if (_data_->_tmp74_ > 0) {
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp75_ = _data_->self->priv->summary;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp76_ = NULL;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp76_ = _ ("Port");
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp77_ = _data_->uri;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp78_ = _data_->_tmp77_->port;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp79_ = NULL;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp79_ = g_strdup_printf ("%i", _data_->_tmp78_);
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp80_ = _data_->_tmp79_;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						boxes_wizard_wizard_summary_add_property (_data_->_tmp75_, _data_->_tmp76_, _data_->_tmp80_);
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp80_);
#line 2484 "wizard.c"
					}
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					break;
#line 2488 "wizard.c"
				}
			}
		}
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp81_ = _data_->self->priv->source;
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp82_ = boxes_collection_source_get_source_type (_data_->_tmp81_);
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp83_ = _data_->_tmp82_;
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp84_ = _data_->_tmp83_;
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp85_ = g_strcmp0 (_data_->_tmp84_, "libvirt") == 0;
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp84_);
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp85_) {
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp86_ = _data_->self->priv->review_label;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp87_ = NULL;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp87_ = _ ("Will add boxes for all systems available from this account:");
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			gtk_label_set_text (_data_->_tmp86_, _data_->_tmp87_);
#line 2514 "wizard.c"
		}
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_xmlFreeURI0 (_data_->uri);
#line 2518 "wizard.c"
	} else {
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_data_->_tmp88_ = _data_->self->priv->vm_creator;
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp88_ != NULL) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp89_ = _data_->self->priv->vm_creator;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp90_ = boxes_vm_creator_get_install_media (_data_->_tmp89_);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp91_ = _data_->_tmp90_;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp92_ = NULL;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp92_ = boxes_installer_media_get_vm_properties (_data_->_tmp91_);
#line 2534 "wizard.c"
			{
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_data_->property_collection = _data_->_tmp92_;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				for (_data_->property_it = _data_->property_collection; _data_->property_it != NULL; _data_->property_it = _data_->property_it->next) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->_tmp93_ = _boxes_pair_ref0 ((BoxesPair*) _data_->property_it->data);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_data_->property = _data_->_tmp93_;
#line 2544 "wizard.c"
					{
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp94_ = _data_->self->priv->summary;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp95_ = _data_->property;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp96_ = _data_->_tmp95_->first;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp97_ = _data_->property;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_data_->_tmp98_ = _data_->_tmp97_->second;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						boxes_wizard_wizard_summary_add_property (_data_->_tmp94_, (const gchar*) _data_->_tmp96_, (const gchar*) _data_->_tmp98_);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
						_boxes_pair_unref0 (_data_->property);
#line 2560 "wizard.c"
					}
				}
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				__g_list_free__boxes_pair_unref0_0 (_data_->property_collection);
#line 2565 "wizard.c"
			}
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp99_ = _data_->self->priv->vm_creator;
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp100_ = boxes_vm_creator_get_install_media (_data_->_tmp99_);
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp101_ = _data_->_tmp100_;
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp102_ = _data_->_tmp101_->resources;
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp103_ = osinfo_resources_get_ram (_data_->_tmp102_);
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp104_ = _data_->_tmp103_;
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp105_ = NULL;
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp105_ = g_format_size_full ((guint64) _data_->_tmp104_, G_FORMAT_SIZE_IEC_UNITS);
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->memory = _data_->_tmp105_;
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp106_ = _data_->self->priv->summary;
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp107_ = NULL;
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp107_ = _ ("Memory");
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp108_ = _data_->memory;
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_wizard_summary_add_property (_data_->_tmp106_, _data_->_tmp107_, _data_->_tmp108_);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp109_ = _data_->self->priv->vm_creator;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp110_ = boxes_vm_creator_get_install_media (_data_->_tmp109_);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp111_ = _data_->_tmp110_;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp112_ = _data_->_tmp111_->resources;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp113_ = osinfo_resources_get_storage (_data_->_tmp112_);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp114_ = _data_->_tmp113_;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp115_ = NULL;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp115_ = g_format_size_full ((guint64) _data_->_tmp114_, G_FORMAT_SIZE_IEC_UNITS);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->memory);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->memory = _data_->_tmp115_;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp116_ = _data_->self->priv->summary;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp117_ = NULL;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp117_ = _ ("Disk");
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp118_ = _data_->memory;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp119_ = NULL;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp119_ = g_strdup_printf ("%s maximum", _data_->_tmp118_);
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp120_ = _data_->_tmp119_;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp121_ = NULL;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp121_ = _ (_data_->_tmp120_);
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_wizard_summary_add_property (_data_->_tmp116_, _data_->_tmp117_, _data_->_tmp121_);
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp120_);
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp122_ = _data_->self->priv->nokvm_label;
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp123_ = _data_->self->priv->machine;
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp124_ = _data_->_tmp123_->domain_config;
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp125_ = 0;
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_data_->_tmp125_ = gvir_config_domain_get_virt_type (_data_->_tmp124_);
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _data_->_tmp122_, _data_->_tmp125_ != GVIR_CONFIG_DOMAIN_VIRT_KVM);
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->memory);
#line 2651 "wizard.c"
		}
	}
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2660 "wizard.c"
	} else {
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2664 "wizard.c"
	}
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2674 "wizard.c"
	} else {
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2678 "wizard.c"
	}
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2684 "wizard.c"
}


static void g_ptr_array_set (GPtrArray* self, guint index, gpointer data) {
	gpointer _tmp0_;
	guint _tmp1_;
#line 4071 "../vapi/upstream/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4072 "../vapi/upstream/glib-2.0.vapi"
	_tmp0_ = data;
#line 4072 "../vapi/upstream/glib-2.0.vapi"
	data = NULL;
#line 4072 "../vapi/upstream/glib-2.0.vapi"
	g_ptr_array_add (self, _tmp0_);
#line 4073 "../vapi/upstream/glib-2.0.vapi"
	_tmp1_ = index;
#line 4073 "../vapi/upstream/glib-2.0.vapi"
	g_ptr_array_remove_index_fast (self, _tmp1_);
#line 2703 "wizard.c"
}


static void boxes_wizard_add_step (BoxesWizard* self, GtkWidget* widget, const gchar* title, BoxesWizardPage page) {
	GtkNotebook* _tmp0_;
	GtkWidget* _tmp1_;
	BoxesApp* _tmp2_;
	BoxesSidebar* _tmp3_;
	GtkNotebook* _tmp4_;
	GtkWidget* _tmp5_ = NULL;
	GtkVBox* _tmp6_;
	GtkVBox* vbox;
	const gchar* _tmp7_;
	GtkLabel* _tmp8_;
	GtkLabel* label;
	GtkStyleContext* _tmp9_ = NULL;
	GPtrArray* _tmp10_;
	BoxesWizardPage _tmp11_;
	GtkLabel* _tmp12_;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (widget != NULL);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (title != NULL);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->notebook;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = widget;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_notebook_append_page (_tmp0_, _tmp1_, NULL);
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_app_app;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_->sidebar;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_->notebook;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = gtk_notebook_get_nth_page (_tmp4_, (gint) BOXES_SIDEBAR_PAGE_WIZARD);
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GTK_TYPE_VBOX) ? ((GtkVBox*) _tmp5_) : NULL);
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	vbox = _tmp6_;
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp7_ = title;
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp8_ = (GtkLabel*) gtk_label_new (_tmp7_);
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp8_);
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label = _tmp8_;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_margin_left ((GtkWidget*) label, 25);
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) label);
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp9_, "boxes-step-label");
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) label, GTK_ALIGN_START);
#line 372 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) vbox, (GtkWidget*) label, FALSE, FALSE, (guint) 10);
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) vbox);
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp10_ = self->priv->steps;
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp11_ = page;
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp12_ = _g_object_ref0 (label);
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_ptr_array_set (_tmp10_, (guint) _tmp11_, _tmp12_);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 2779 "wizard.c"
}


static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page) {
	gboolean result = FALSE;
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
	BoxesWizardPage _tmp2_;
	gboolean forwards;
	BoxesWizardPage _tmp3_;
	BoxesWizardPage skip_to;
	gboolean _tmp4_ = FALSE;
	BoxesCollectionSource* _tmp5_;
	gboolean _tmp8_;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_;
	gboolean _tmp17_;
	gboolean _tmp19_ = FALSE;
	BoxesVMCreator* _tmp20_;
	gboolean _tmp22_;
	BoxesWizardPage _tmp45_;
	BoxesWizardPage _tmp46_;
#line 380 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = page;
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_page (self);
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	forwards = _tmp0_ > _tmp2_;
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = page;
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	skip_to = _tmp3_;
#line 385 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->source;
#line 385 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp5_ != NULL) {
#line 2820 "wizard.c"
		BoxesWizardPage _tmp6_;
		BoxesWizardPage _tmp7_;
#line 386 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp6_ = page;
#line 386 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 386 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp4_ = (BOXES_WIZARD_PAGE_SOURCE < _tmp7_) && (_tmp7_ < BOXES_WIZARD_PAGE_REVIEW);
#line 2829 "wizard.c"
	} else {
#line 385 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp4_ = FALSE;
#line 2833 "wizard.c"
	}
#line 385 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp8_ = _tmp4_;
#line 385 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp8_) {
#line 2839 "wizard.c"
		BoxesWizardPage _tmp9_ = 0;
		gboolean _tmp10_;
		BoxesWizardPage _tmp13_;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp10_ = forwards;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (_tmp10_) {
#line 2847 "wizard.c"
			BoxesWizardPage _tmp11_;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp11_ = page;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp11_ + 1;
#line 2853 "wizard.c"
		} else {
			BoxesWizardPage _tmp12_;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp12_ = page;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp12_ - 1;
#line 2860 "wizard.c"
		}
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp13_ = _tmp9_;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		skip_to = _tmp13_;
#line 2866 "wizard.c"
	}
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp15_ = forwards;
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (!_tmp15_) {
#line 2872 "wizard.c"
		BoxesWizardPage _tmp16_;
#line 391 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp16_ = page;
#line 391 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp14_ = _tmp16_ == BOXES_WIZARD_PAGE_PREPARATION;
#line 2878 "wizard.c"
	} else {
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp14_ = FALSE;
#line 2882 "wizard.c"
	}
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp17_ = _tmp14_;
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp17_) {
#line 2888 "wizard.c"
		BoxesWizardPage _tmp18_;
#line 392 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp18_ = page;
#line 392 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		skip_to = _tmp18_ - 1;
#line 2894 "wizard.c"
	}
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp20_ = self->priv->vm_creator;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp20_ != NULL) {
#line 2900 "wizard.c"
		BoxesWizardPage _tmp21_;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp21_ = page;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp19_ = _tmp21_ == BOXES_WIZARD_PAGE_SETUP;
#line 2906 "wizard.c"
	} else {
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp19_ = FALSE;
#line 2910 "wizard.c"
	}
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp22_ = _tmp19_;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp22_) {
#line 2916 "wizard.c"
		BoxesVMCreator* _tmp23_;
		BoxesInstallerMedia* _tmp24_;
		BoxesInstallerMedia* _tmp25_;
		gboolean _tmp26_;
		gboolean _tmp27_;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp23_ = self->priv->vm_creator;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp24_ = boxes_vm_creator_get_install_media (_tmp23_);
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp25_ = _tmp24_;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp26_ = boxes_installer_media_get_need_user_input_for_vm_creation (_tmp25_);
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp27_ = _tmp26_;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		if (!_tmp27_) {
#line 2934 "wizard.c"
			BoxesWizardPage _tmp28_ = 0;
			gboolean _tmp29_;
			BoxesWizardPage _tmp32_;
			gboolean _tmp33_ = FALSE;
			gboolean _tmp34_ = FALSE;
			BoxesVMCreator* _tmp35_;
			BoxesInstallerMedia* _tmp36_;
			BoxesInstallerMedia* _tmp37_;
			gboolean _tmp38_;
			gboolean _tmp39_;
			gboolean _tmp41_;
			gboolean _tmp43_;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp29_ = forwards;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_tmp29_) {
#line 2951 "wizard.c"
				BoxesWizardPage _tmp30_;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp30_ = page;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp28_ = _tmp30_ + 1;
#line 2957 "wizard.c"
			} else {
				BoxesWizardPage _tmp31_;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp31_ = page;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp28_ = _tmp31_ - 1;
#line 2964 "wizard.c"
			}
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp32_ = _tmp28_;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			skip_to = _tmp32_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp35_ = self->priv->vm_creator;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp36_ = boxes_vm_creator_get_install_media (_tmp35_);
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp37_ = _tmp36_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp38_ = boxes_installer_media_get_live (_tmp37_);
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp39_ = _tmp38_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_tmp39_) {
#line 2982 "wizard.c"
				gboolean _tmp40_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp40_ = forwards;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp34_ = _tmp40_;
#line 2988 "wizard.c"
			} else {
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp34_ = FALSE;
#line 2992 "wizard.c"
			}
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp41_ = _tmp34_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_tmp41_) {
#line 2998 "wizard.c"
				gboolean _tmp42_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp42_ = self->priv->skip_review_for_live;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp33_ = _tmp42_;
#line 3004 "wizard.c"
			} else {
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp33_ = FALSE;
#line 3008 "wizard.c"
			}
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp43_ = _tmp33_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			if (_tmp43_) {
#line 3014 "wizard.c"
				BoxesWizardPage _tmp44_;
#line 401 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp44_ = skip_to;
#line 401 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				skip_to = _tmp44_ + 1;
#line 3020 "wizard.c"
			}
		}
	}
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp45_ = skip_to;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp46_ = page;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp45_ != _tmp46_) {
#line 3030 "wizard.c"
		BoxesWizardPage _tmp47_;
#line 405 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp47_ = skip_to;
#line 405 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp47_);
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return result;
#line 3040 "wizard.c"
	}
#line 409 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	result = FALSE;
#line 409 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return result;
#line 3046 "wizard.c"
}


static void __lambda114_ (BoxesWizard* self) {
	BoxesWizardSource* _tmp0_;
	BoxesApp* _tmp1_;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_destroy_machine (self);
#line 546 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 546 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp0_, BOXES_SOURCE_PAGE_MAIN);
#line 547 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_app_app;
#line 547 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 3063 "wizard.c"
}


static void ___lambda114__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 544 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	__lambda114_ (self);
#line 3070 "wizard.c"
}


static void __lambda115_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
#line 556 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 556 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 556 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ - 1);
#line 3083 "wizard.c"
}


static void ___lambda115__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 555 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	__lambda115_ (self);
#line 3090 "wizard.c"
}


static void __lambda116_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
#line 566 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 566 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 566 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ + 1);
#line 3103 "wizard.c"
}


static void ___lambda116__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 565 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	__lambda116_ (self);
#line 3110 "wizard.c"
}


static void boxes_wizard_setup_ui (BoxesWizard* self) {
	GtkNotebook* _tmp0_;
	GtkNotebook* _tmp1_;
	GtkNotebook* _tmp2_;
	GtkNotebook* _tmp3_;
	GtkNotebook* _tmp4_;
	GtkStyleContext* _tmp5_ = NULL;
	GtkNotebook* _tmp6_;
	GtkClutterActor* _tmp7_;
	GtkClutterActor* _tmp8_;
	GtkWidget* _tmp9_ = NULL;
	GtkStyleContext* _tmp10_ = NULL;
	GtkClutterActor* _tmp11_;
	GtkClutterActor* _tmp12_;
	GtkHBox* _tmp13_;
	GtkHBox* hbox;
	GtkHBox* _tmp14_;
	GtkHBox* _tmp15_;
	const gchar* _tmp16_ = NULL;
	GtkHBox* _tmp17_;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_;
	GtkImage* _tmp20_;
	GtkImage* _tmp21_;
	GtkLabel* _tmp22_;
	GtkLabel* label;
	GtkLabel* _tmp23_;
	GtkStyleContext* _tmp24_ = NULL;
	GtkLabel* _tmp25_;
	const gchar* _tmp26_ = NULL;
	GtkLabel* _tmp27_;
	GtkLabel* _tmp28_;
	GtkLabel* _tmp29_;
	GtkHBox* _tmp30_;
	GtkLabel* _tmp31_;
	GtkHBox* _tmp32_;
	GtkVBox* _tmp33_;
	GtkVBox* vbox;
	GtkVBox* _tmp34_;
	GtkVBox* _tmp35_;
	GtkVBox* _tmp36_;
	const gchar* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	GtkLabel* _tmp39_;
	GtkLabel* _tmp40_;
	GtkStyleContext* _tmp41_ = NULL;
	GtkLabel* _tmp42_;
	GtkLabel* _tmp43_;
	GtkLabel* _tmp44_;
	GtkVBox* _tmp45_;
	GtkLabel* _tmp46_;
	GtkVBox* _tmp47_;
	BoxesWizardSource* _tmp48_;
	GtkWidget* _tmp49_;
	GtkWidget* _tmp50_;
	BoxesWizardSource* _tmp51_;
	GtkWidget* _tmp52_;
	GtkWidget* _tmp53_;
	BoxesWizardSource* _tmp54_;
	GtkWidget* _tmp55_;
	GtkWidget* _tmp56_;
	const gchar* _tmp57_ = NULL;
	GtkLabel* _tmp58_;
	GtkLabel* _tmp59_;
	GtkStyleContext* _tmp60_ = NULL;
	GtkLabel* _tmp61_;
	GtkLabel* _tmp62_;
	GtkLabel* _tmp63_;
	GtkVBox* _tmp64_;
	GtkLabel* _tmp65_;
	GtkVBox* _tmp66_;
	GtkVBox* _tmp67_;
	GtkVBox* _tmp68_;
	GtkVBox* _tmp69_;
	GtkVBox* _tmp70_;
	const gchar* _tmp71_ = NULL;
	const gchar* _tmp72_ = NULL;
	GtkLabel* _tmp73_;
	GtkLabel* _tmp74_;
	GtkStyleContext* _tmp75_ = NULL;
	GtkLabel* _tmp76_;
	GtkLabel* _tmp77_;
	GtkLabel* _tmp78_;
	GtkVBox* _tmp79_;
	GtkLabel* _tmp80_;
	GtkHBox* _tmp81_;
	GtkHBox* _tmp82_;
	GtkHBox* _tmp83_;
	GtkVBox* _tmp84_;
	GtkHBox* _tmp85_;
	GtkImage* _tmp86_;
	GtkImage* _tmp87_;
	GtkHBox* _tmp88_;
	GtkImage* _tmp89_;
	GtkVBox* _tmp90_;
	GtkVBox* prep_vbox;
	GtkHBox* _tmp91_;
	const gchar* _tmp92_ = NULL;
	GtkLabel* _tmp93_;
	GtkLabel* _tmp94_;
	GtkStyleContext* _tmp95_ = NULL;
	GtkLabel* _tmp96_;
	GtkProgressBar* _tmp97_;
	GtkProgressBar* _tmp98_;
	GtkVBox* _tmp99_;
	GtkVBox* _tmp100_;
	GtkVBox* _tmp101_;
	GtkVBox* _tmp102_;
	GtkVBox* _tmp103_;
	const gchar* _tmp104_ = NULL;
	GtkVBox* _tmp105_;
	GtkVBox* _tmp106_;
	GtkVBox* _tmp107_;
	GtkVBox* _tmp108_;
	GtkVBox* _tmp109_;
	const gchar* _tmp110_ = NULL;
	GtkLabel* _tmp111_;
	GtkLabel* _tmp112_;
	GtkStyleContext* _tmp113_ = NULL;
	GtkLabel* _tmp114_;
	GtkLabel* _tmp115_;
	GtkLabel* _tmp116_;
	GtkVBox* _tmp117_;
	GtkLabel* _tmp118_;
	BoxesWizardWizardSummary* _tmp119_;
	GtkVBox* _tmp120_;
	BoxesWizardWizardSummary* _tmp121_;
	GtkWidget* _tmp122_;
	GtkWidget* _tmp123_;
	const gchar* _tmp124_ = NULL;
	GtkLabel* _tmp125_;
	GtkLabel* _tmp126_;
	GtkStyleContext* _tmp127_ = NULL;
	GtkLabel* _tmp128_;
	GtkLabel* _tmp129_;
	GtkVBox* _tmp130_;
	GtkLabel* _tmp131_;
	GtkVBox* _tmp132_;
	BoxesApp* _tmp133_;
	BoxesTopbar* _tmp134_;
	GtkNotebook* _tmp135_;
	GtkWidget* _tmp136_ = NULL;
	GtkHBox* _tmp137_;
	GtkToolbar* _tmp138_;
	GtkToolbar* toolbar;
	GtkStyleContext* _tmp139_ = NULL;
	GtkHBox* _tmp140_;
	const gchar* _tmp141_ = NULL;
	GtkLabel* _tmp142_;
	GtkLabel* _tmp143_;
	GtkLabel* _tmp144_;
	GtkLabel* _tmp145_;
	GtkToolItem* _tmp146_;
	GtkToolItem* tool_item;
	GtkToolItem* _tmp147_;
	GtkToolItem* _tmp148_;
	GtkLabel* _tmp149_;
	GtkToolItem* _tmp150_;
	GtkButton* _tmp151_;
	GtkToolItem* _tmp152_;
	GtkToolItem* _tmp153_;
	GtkButton* _tmp154_;
	GtkToolItem* _tmp155_;
	GtkButton* _tmp156_;
	GtkButton* _tmp157_;
	GtkToolItem* _tmp158_;
	GtkToolItem* _tmp159_;
	GtkButton* _tmp160_;
	GtkToolItem* _tmp161_;
	GtkToolItem* _tmp162_;
	GtkButton* _tmp163_;
	const gchar* _tmp164_ = NULL;
	GtkButton* _tmp165_;
	GtkToolItem* _tmp166_;
	GtkToolItem* _tmp167_;
	GtkButton* _tmp168_;
	GtkToolItem* _tmp169_;
	GtkToolItem* _tmp170_;
	GtkButton* _tmp171_;
	GtkStyleContext* _tmp172_ = NULL;
	GtkButton* _tmp173_;
	GtkHBox* _tmp174_;
	GtkNotebook* _tmp175_;
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 413 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = (GtkNotebook*) gtk_notebook_new ();
#line 413 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp0_);
#line 413 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->notebook);
#line 413 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->notebook = _tmp0_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->notebook;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkWidget*) _tmp1_, "margin", 15, NULL);
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->notebook;
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkWidget*) _tmp2_, "width-request", 500, NULL);
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->notebook;
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_notebook_set_show_tabs (_tmp3_, FALSE);
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->notebook;
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp5_, "boxes-bg");
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->notebook;
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp7_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp6_);
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp7_);
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->gtk_actor = _tmp7_;
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->gtk_actor;
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp9_ = gtk_clutter_actor_get_widget (_tmp8_);
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp10_ = gtk_widget_get_style_context (_tmp9_);
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp10_, "boxes-bg");
#line 420 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp11_ = self->priv->gtk_actor;
#line 420 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp11_, "wizard");
#line 421 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp12_ = self->priv->gtk_actor;
#line 421 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	clutter_actor_set_opacity ((ClutterActor*) _tmp12_, (guint) 0);
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp13_ = (GtkHBox*) gtk_hbox_new (FALSE, 10);
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp13_);
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	hbox = _tmp13_;
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp14_ = hbox;
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp14_, GTK_ALIGN_CENTER);
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp15_ = hbox;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp16_ = _ ("Introduction");
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp15_, _tmp16_, BOXES_WIZARD_PAGE_INTRODUCTION);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp17_ = hbox;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp18_ = boxes_get_pixmap ("boxes-create.png");
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp19_ = _tmp18_;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp20_ = (GtkImage*) gtk_image_new_from_file (_tmp19_);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp20_);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp21_ = _tmp20_;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_container_add ((GtkContainer*) _tmp17_, (GtkWidget*) _tmp21_);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp21_);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp19_);
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp22_ = (GtkLabel*) gtk_label_new (NULL);
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp22_);
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label = _tmp22_;
#line 429 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp23_ = label;
#line 429 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp24_ = gtk_widget_get_style_context ((GtkWidget*) _tmp23_);
#line 429 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp24_, "boxes-wizard-label");
#line 430 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp25_ = label;
#line 430 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp26_ = _ ("Creating a Box will allow you to use another operating system directly" \
" from your existing login.\n" \
"\n" \
"You may connect to an existing machine <b><i>over the network</i></b> " \
"or create a <b><i>virtual machine</i></b> that runs locally on your ow" \
"n.");
#line 430 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_markup (_tmp25_, _tmp26_);
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp27_ = label;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp27_, "wrap", TRUE, NULL);
#line 433 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp28_ = label;
#line 433 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp28_, 30);
#line 434 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp29_ = label;
#line 434 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp29_, 40);
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp30_ = hbox;
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp31_ = label;
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_container_add ((GtkContainer*) _tmp30_, (GtkWidget*) _tmp31_);
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp32_ = hbox;
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp32_);
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp33_ = (GtkVBox*) gtk_vbox_new (FALSE, 30);
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp33_);
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	vbox = _tmp33_;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp34_ = vbox;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp34_, GTK_ALIGN_CENTER);
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp35_ = vbox;
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp35_, GTK_ALIGN_CENTER);
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp36_ = vbox;
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp37_ = _ ("Source Selection");
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp36_, _tmp37_, BOXES_WIZARD_PAGE_SOURCE);
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp38_ = _ ("Insert operating system installation media or select a source below");
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp39_ = (GtkLabel*) gtk_label_new (_tmp38_);
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp39_);
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label = _tmp39_;
#line 444 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp40_ = label;
#line 444 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp41_ = gtk_widget_get_style_context ((GtkWidget*) _tmp40_);
#line 444 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp41_, "boxes-wizard-label");
#line 445 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp42_ = label;
#line 445 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp42_, "wrap", TRUE, NULL);
#line 447 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp43_ = label;
#line 447 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp43_, 30);
#line 448 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp44_ = label;
#line 448 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp44_, "xalign", 0.0f, NULL);
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp45_ = vbox;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp46_ = label;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp45_, (GtkWidget*) _tmp46_, FALSE, FALSE, (guint) 0);
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp47_ = vbox;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp48_ = self->priv->wizard_source;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp49_ = boxes_wizard_source_get_widget (_tmp48_);
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp50_ = _tmp49_;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp47_, _tmp50_, FALSE, FALSE, (guint) 0);
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp51_ = self->priv->wizard_source;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp52_ = boxes_wizard_source_get_widget (_tmp51_);
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp53_ = _tmp52_;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_hexpand (_tmp53_, TRUE);
#line 452 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp54_ = self->priv->wizard_source;
#line 452 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp55_ = boxes_wizard_source_get_widget (_tmp54_);
#line 452 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp56_ = _tmp55_;
#line 452 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign (_tmp56_, GTK_ALIGN_CENTER);
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp57_ = _ ("Any trademarks shown above are used merely for identification of softw" \
"are products you have already obtained and are the property of their r" \
"espective owners.");
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp58_ = (GtkLabel*) gtk_label_new (_tmp57_);
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp58_);
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label = _tmp58_;
#line 454 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp59_ = label;
#line 454 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp60_ = gtk_widget_get_style_context ((GtkWidget*) _tmp59_);
#line 454 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp60_, "boxes-logo-notice-label");
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp61_ = label;
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp61_, "wrap", TRUE, NULL);
#line 457 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp62_ = label;
#line 457 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp62_, 30);
#line 458 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp63_ = label;
#line 458 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp63_, 50);
#line 459 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp64_ = vbox;
#line 459 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp65_ = label;
#line 459 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp64_, (GtkWidget*) _tmp65_, FALSE, FALSE, (guint) 0);
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp66_ = vbox;
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp66_);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp67_ = (GtkVBox*) gtk_vbox_new (FALSE, 30);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp67_);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	vbox = _tmp67_;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp68_ = vbox;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp68_, GTK_ALIGN_CENTER);
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp69_ = vbox;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp69_, GTK_ALIGN_CENTER);
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp70_ = vbox;
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp71_ = _ ("Preparation");
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp70_, _tmp71_, BOXES_WIZARD_PAGE_PREPARATION);
#line 467 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp72_ = _ ("Preparing to create new box");
#line 467 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp73_ = (GtkLabel*) gtk_label_new (_tmp72_);
#line 467 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp73_);
#line 467 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 467 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label = _tmp73_;
#line 468 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp74_ = label;
#line 468 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp75_ = gtk_widget_get_style_context ((GtkWidget*) _tmp74_);
#line 468 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp75_, "boxes-wizard-label");
#line 469 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp76_ = label;
#line 469 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp76_, "wrap", TRUE, NULL);
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp77_ = label;
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp77_, 30);
#line 472 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp78_ = label;
#line 472 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp78_, "xalign", 0.0f, NULL);
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp79_ = vbox;
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp80_ = label;
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp79_, (GtkWidget*) _tmp80_, FALSE, FALSE, (guint) 0);
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp81_ = (GtkHBox*) gtk_hbox_new (FALSE, 10);
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp81_);
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (hbox);
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	hbox = _tmp81_;
#line 476 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp82_ = hbox;
#line 476 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp82_, GTK_ALIGN_CENTER);
#line 477 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp83_ = hbox;
#line 477 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp83_, GTK_ALIGN_CENTER);
#line 478 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp84_ = vbox;
#line 478 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp85_ = hbox;
#line 478 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp84_, (GtkWidget*) _tmp85_, TRUE, TRUE, (guint) 0);
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp86_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp86_);
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->installer_image);
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->installer_image = _tmp86_;
#line 481 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp87_ = self->priv->installer_image;
#line 481 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_image_set_pixel_size (_tmp87_, 128);
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp88_ = hbox;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp89_ = self->priv->installer_image;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp88_, (GtkWidget*) _tmp89_, FALSE, FALSE, (guint) 0);
#line 483 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp90_ = (GtkVBox*) gtk_vbox_new (TRUE, 10);
#line 483 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp90_);
#line 483 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	prep_vbox = _tmp90_;
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) prep_vbox, GTK_ALIGN_CENTER);
#line 485 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp91_ = hbox;
#line 485 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp91_, (GtkWidget*) prep_vbox, TRUE, TRUE, (guint) 0);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp92_ = _ ("Analyzing installer media.");
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp93_ = (GtkLabel*) gtk_label_new (_tmp92_);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp93_);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label = _tmp93_;
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp94_ = label;
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp95_ = gtk_widget_get_style_context ((GtkWidget*) _tmp94_);
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp95_, "boxes-wizard-label");
#line 488 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp96_ = label;
#line 488 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) prep_vbox, (GtkWidget*) _tmp96_, FALSE, FALSE, (guint) 0);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp97_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp97_);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_progress);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->prep_progress = _tmp97_;
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp98_ = self->priv->prep_progress;
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) prep_vbox, (GtkWidget*) _tmp98_, FALSE, FALSE, (guint) 0);
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp99_ = vbox;
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp99_);
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp100_ = (GtkVBox*) gtk_vbox_new (FALSE, 30);
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp100_);
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->setup_vbox);
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->setup_vbox = _tmp100_;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp101_ = self->priv->setup_vbox;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp101_, GTK_ALIGN_CENTER);
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp102_ = self->priv->setup_vbox;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp102_, GTK_ALIGN_CENTER);
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp103_ = self->priv->setup_vbox;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp104_ = _ ("Setup");
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp103_, _tmp104_, BOXES_WIZARD_PAGE_SETUP);
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp105_ = self->priv->setup_vbox;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp105_);
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp106_ = (GtkVBox*) gtk_vbox_new (FALSE, 30);
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp106_);
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	vbox = _tmp106_;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp107_ = vbox;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp107_, GTK_ALIGN_CENTER);
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp108_ = vbox;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp108_, GTK_ALIGN_CENTER);
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp109_ = vbox;
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp110_ = _ ("Review");
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp109_, _tmp110_, BOXES_WIZARD_PAGE_REVIEW);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp111_ = (GtkLabel*) gtk_label_new (NULL);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp111_);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_label);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->review_label = _tmp111_;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp112_ = self->priv->review_label;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp113_ = gtk_widget_get_style_context ((GtkWidget*) _tmp112_);
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp113_, "boxes-wizard-label");
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp114_ = self->priv->review_label;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp114_, "xalign", 0.0f, NULL);
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp115_ = self->priv->review_label;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp115_, "wrap", TRUE, NULL);
#line 510 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp116_ = self->priv->review_label;
#line 510 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp116_, 30);
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp117_ = vbox;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp118_ = self->priv->review_label;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp117_, (GtkWidget*) _tmp118_, FALSE, FALSE, (guint) 0);
#line 513 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp119_ = boxes_wizard_wizard_summary_new ();
#line 513 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->summary);
#line 513 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->summary = _tmp119_;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp120_ = vbox;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp121_ = self->priv->summary;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp122_ = boxes_wizard_wizard_summary_get_widget (_tmp121_);
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp123_ = _tmp122_;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp120_, _tmp123_, TRUE, TRUE, (guint) 0);
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp124_ = _ ("Virtualization extensions are unavailable on your system. Expect this " \
"box to be extremely slow. If your system is recent enough (made in or " \
"after 2008), these extensions are probably available on your system an" \
"d you may need to enable them in your system's BIOS setup.");
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp125_ = (GtkLabel*) gtk_label_new (_tmp124_);
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp125_);
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->nokvm_label);
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->nokvm_label = _tmp125_;
#line 516 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp126_ = self->priv->nokvm_label;
#line 516 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp127_ = gtk_widget_get_style_context ((GtkWidget*) _tmp126_);
#line 516 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp127_, "boxes-logo-notice-label");
#line 517 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp128_ = self->priv->nokvm_label;
#line 517 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp128_, "wrap", TRUE, NULL);
#line 518 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp129_ = self->priv->nokvm_label;
#line 518 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp129_, 50);
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp130_ = vbox;
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp131_ = self->priv->nokvm_label;
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp130_, (GtkWidget*) _tmp131_, FALSE, FALSE, (guint) 0);
#line 520 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp132_ = vbox;
#line 520 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp132_);
#line 523 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp133_ = boxes_app_app;
#line 523 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp134_ = _tmp133_->topbar;
#line 523 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp135_ = _tmp134_->notebook;
#line 523 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp136_ = gtk_notebook_get_nth_page (_tmp135_, (gint) BOXES_TOPBAR_PAGE_WIZARD);
#line 523 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp137_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp136_, GTK_TYPE_HBOX) ? ((GtkHBox*) _tmp136_) : NULL);
#line 523 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (hbox);
#line 523 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	hbox = _tmp137_;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp138_ = (GtkToolbar*) gtk_toolbar_new ();
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp138_);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	toolbar = _tmp138_;
#line 526 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_toolbar_set_icon_size (toolbar, (gint) GTK_ICON_SIZE_MENU);
#line 527 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp139_ = gtk_widget_get_style_context ((GtkWidget*) toolbar);
#line 527 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp139_, GTK_STYLE_CLASS_MENUBAR);
#line 528 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_toolbar_set_show_arrow (toolbar, FALSE);
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp140_ = hbox;
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start ((GtkBox*) _tmp140_, (GtkWidget*) toolbar, TRUE, TRUE, (guint) 0);
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp141_ = _ ("Create a Box");
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp142_ = (GtkLabel*) gtk_label_new (_tmp141_);
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp142_);
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label = _tmp142_;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp143_ = label;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_name ((GtkWidget*) _tmp143_, "TopbarLabel");
#line 533 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp144_ = label;
#line 533 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp144_, GTK_ALIGN_START);
#line 534 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp145_ = label;
#line 534 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_margin_left ((GtkWidget*) _tmp145_, 15);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp146_ = gtk_tool_item_new ();
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp146_);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	tool_item = _tmp146_;
#line 536 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp147_ = tool_item;
#line 536 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_tool_item_set_expand (_tmp147_, TRUE);
#line 537 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp148_ = tool_item;
#line 537 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp149_ = label;
#line 537 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkContainer*) _tmp148_, "child", (GtkWidget*) _tmp149_, NULL);
#line 538 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp150_ = tool_item;
#line 538 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_toolbar_insert (toolbar, _tmp150_, 0);
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp151_ = (GtkButton*) gtk_button_new_from_stock (GTK_STOCK_CANCEL);
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp151_);
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->cancel_button = _tmp151_;
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp152_ = gtk_tool_item_new ();
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp152_);
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (tool_item);
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	tool_item = _tmp152_;
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp153_ = tool_item;
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp154_ = self->priv->cancel_button;
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkContainer*) _tmp153_, "child", (GtkWidget*) _tmp154_, NULL);
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp155_ = tool_item;
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_toolbar_insert (toolbar, _tmp155_, 1);
#line 544 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp156_ = self->priv->cancel_button;
#line 544 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp156_, "clicked", (GCallback) ___lambda114__gtk_button_clicked, self, 0);
#line 550 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp157_ = (GtkButton*) gtk_button_new_from_stock (GTK_STOCK_GO_BACK);
#line 550 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp157_);
#line 550 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 550 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->back_button = _tmp157_;
#line 551 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp158_ = gtk_tool_item_new ();
#line 551 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp158_);
#line 551 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (tool_item);
#line 551 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	tool_item = _tmp158_;
#line 552 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp159_ = tool_item;
#line 552 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp160_ = self->priv->back_button;
#line 552 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkContainer*) _tmp159_, "child", (GtkWidget*) _tmp160_, NULL);
#line 553 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp161_ = tool_item;
#line 553 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_margin_left ((GtkWidget*) _tmp161_, 20);
#line 554 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp162_ = tool_item;
#line 554 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_toolbar_insert (toolbar, _tmp162_, 2);
#line 555 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp163_ = self->priv->back_button;
#line 555 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp163_, "clicked", (GCallback) ___lambda115__gtk_button_clicked, self, 0);
#line 559 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp164_ = _ ("C_ontinue");
#line 559 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp165_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp164_);
#line 559 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp165_);
#line 559 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->next_button);
#line 559 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->next_button = _tmp165_;
#line 560 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp166_ = gtk_tool_item_new ();
#line 560 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp166_);
#line 560 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (tool_item);
#line 560 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	tool_item = _tmp166_;
#line 561 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp167_ = tool_item;
#line 561 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp168_ = self->priv->next_button;
#line 561 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkContainer*) _tmp167_, "child", (GtkWidget*) _tmp168_, NULL);
#line 562 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp169_ = tool_item;
#line 562 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_margin_left ((GtkWidget*) _tmp169_, 5);
#line 563 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp170_ = tool_item;
#line 563 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_toolbar_insert (toolbar, _tmp170_, 3);
#line 564 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp171_ = self->priv->next_button;
#line 564 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp172_ = gtk_widget_get_style_context ((GtkWidget*) _tmp171_);
#line 564 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp172_, "boxes-continue");
#line 565 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp173_ = self->priv->next_button;
#line 565 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp173_, "clicked", (GCallback) ___lambda116__gtk_button_clicked, self, 0);
#line 569 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp174_ = hbox;
#line 569 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp174_);
#line 570 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp175_ = self->priv->notebook;
#line 570 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp175_);
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (tool_item);
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (toolbar);
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (prep_vbox);
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (hbox);
#line 4017 "wizard.c"
}


void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live) {
	BoxesApp* _tmp0_;
	gboolean _tmp1_;
	BoxesWizardSource* _tmp2_;
	BoxesWizardSource* _tmp3_;
	const gchar* _tmp4_;
#line 573 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 573 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri != NULL);
#line 574 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_app_app;
#line 574 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 575 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = skip_review_for_live;
#line 575 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->skip_review_for_live = _tmp1_;
#line 577 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 578 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 578 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp2_, BOXES_SOURCE_PAGE_URL);
#line 579 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 579 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = uri;
#line 579 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp3_, _tmp4_);
#line 580 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 4053 "wizard.c"
}


static void boxes_wizard_real_ui_state_changed (BoxesUI* base) {
	BoxesWizard * self;
	guint opacity;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
	ClutterActor* _tmp2_;
	ClutterActor* _tmp3_;
	guint _tmp4_;
#line 583 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 584 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	opacity = (guint) 0;
#line 585 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 585 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 585 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	switch (_tmp1_) {
#line 585 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case BOXES_UI_STATE_WIZARD:
#line 4077 "wizard.c"
		{
#line 587 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_INTRODUCTION);
#line 588 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			opacity = (guint) 255;
#line 589 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 4085 "wizard.c"
		}
		default:
#line 585 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		break;
#line 4090 "wizard.c"
	}
#line 592 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 592 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 592 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = opacity;
#line 592 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_fade_actor (_tmp3_, _tmp4_);
#line 4100 "wizard.c"
}


static void boxes_wizard_destroy_machine (BoxesWizard* self) {
	BoxesLibvirtMachine* _tmp0_;
#line 595 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 596 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->machine;
#line 596 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 4112 "wizard.c"
		BoxesApp* _tmp1_;
		BoxesLibvirtMachine* _tmp2_;
#line 597 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp1_ = boxes_app_app;
#line 597 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->machine;
#line 597 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_app_delete_machine (_tmp1_, (BoxesMachine*) _tmp2_, TRUE);
#line 598 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self->priv->machine);
#line 598 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		self->priv->machine = NULL;
#line 4125 "wizard.c"
	}
}


static ClutterActor* boxes_wizard_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesWizard* self;
	GtkClutterActor* _tmp0_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	result = (ClutterActor*) _tmp0_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return result;
#line 4142 "wizard.c"
}


static BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self) {
	BoxesWizardPage result;
	BoxesWizardPage _tmp0_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_page;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return result;
#line 4157 "wizard.c"
}


static void _boxes_wizard_page_____lambda109_ (BoxesWizard* self, GObject* source, GAsyncResult* _result_) {
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	GtkButton* _tmp2_;
	GAsyncResult* _tmp3_;
	gboolean _tmp4_ = FALSE;
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->back_button;
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, TRUE);
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->next_button;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, TRUE);
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->cancel_button;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, TRUE);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = _result_;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = boxes_wizard_review_finish (self, _tmp3_);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (!_tmp4_) {
#line 4187 "wizard.c"
		BoxesWizardPage _tmp5_;
		BoxesWizardPage _tmp6_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_wizard_get_page (self);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp6_ - 1);
#line 4196 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda109__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda109_ (self, source_object, res);
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 4206 "wizard.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	return result;
#line 4221 "wizard.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4093 "../vapi/upstream/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4093 "../vapi/upstream/glib-2.0.vapi"
	_tmp0_ = value;
#line 4093 "../vapi/upstream/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 4233 "wizard.c"
}


static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value) {
	GtkButton* _tmp0_;
	BoxesWizardPage _tmp1_;
	BoxesWizardPage _tmp2_;
	BoxesWizardPage _tmp3_;
	BoxesWizardPage _tmp4_;
	gboolean forwards;
	BoxesWizardPage _tmp5_;
	gboolean _tmp12_;
	BoxesWizardPage _tmp28_;
	gboolean _tmp29_ = FALSE;
	BoxesWizardPage _tmp30_;
	GtkNotebook* _tmp31_;
	BoxesWizardPage _tmp32_;
	GPtrArray* _tmp45_;
	BoxesWizardPage _tmp46_;
	BoxesWizardPage _tmp47_;
	gconstpointer _tmp48_ = NULL;
	GdkColor _tmp49_ = {0};
	const gchar* _tmp50_ = NULL;
	BoxesWizardPage _tmp51_;
	BoxesWizardPage _tmp52_;
	GtkButton* _tmp55_;
	const gchar* _tmp56_;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->back_button;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = value;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp1_ != BOXES_WIZARD_PAGE_INTRODUCTION);
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = value;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_wizard_get_page (self);
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	forwards = _tmp2_ > _tmp4_;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = value;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	switch (_tmp5_) {
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_INTRODUCTION:
#line 4283 "wizard.c"
		{
			GtkButton* _tmp6_;
			GtkButton* _tmp7_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->next_button;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, TRUE);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp7_ = self->priv->next_button;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp7_);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 4297 "wizard.c"
		}
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_SOURCE:
#line 4301 "wizard.c"
		{
			BoxesWizardSource* _tmp8_;
			BoxesWizardSource* _tmp9_;
			BoxesSourcePage _tmp10_;
			BoxesSourcePage _tmp11_;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp8_ = self->priv->wizard_source;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp9_ = self->priv->wizard_source;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp10_ = boxes_wizard_source_get_page (_tmp9_);
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp11_ = _tmp10_;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_set_page (_tmp8_, _tmp11_);
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 4319 "wizard.c"
		}
		default:
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		break;
#line 4324 "wizard.c"
	}
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp12_ = forwards;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp12_) {
#line 4330 "wizard.c"
		BoxesWizardPage _tmp13_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp13_ = value;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		switch (_tmp13_) {
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SOURCE:
#line 4338 "wizard.c"
			{
				BoxesWizardSource* _tmp14_;
				BoxesWizardSource* _tmp15_;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp14_ = self->priv->wizard_source;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				boxes_wizard_source_set_selected (_tmp14_, NULL);
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp15_ = self->priv->wizard_source;
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				boxes_wizard_source_set_page (_tmp15_, BOXES_SOURCE_PAGE_MAIN);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				break;
#line 4352 "wizard.c"
			}
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_PREPARATION:
#line 4356 "wizard.c"
			{
				gboolean _tmp16_ = FALSE;
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp16_ = boxes_wizard_prepare (self);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (!_tmp16_) {
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					return;
#line 4365 "wizard.c"
				}
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				break;
#line 4369 "wizard.c"
			}
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SETUP:
#line 4373 "wizard.c"
			{
				gboolean _tmp17_ = FALSE;
#line 69 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp17_ = boxes_wizard_setup (self);
#line 69 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (!_tmp17_) {
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					return;
#line 4382 "wizard.c"
				}
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				break;
#line 4386 "wizard.c"
			}
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 4390 "wizard.c"
			{
				GtkButton* _tmp18_;
				GtkButton* _tmp19_;
				GtkButton* _tmp20_;
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp18_ = self->priv->back_button;
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp18_, FALSE);
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp19_ = self->priv->next_button;
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp19_, FALSE);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp20_ = self->priv->cancel_button;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp20_, FALSE);
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				boxes_wizard_review (self, __boxes_wizard_page_____lambda109__gasync_ready_callback, g_object_ref (self));
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				break;
#line 4411 "wizard.c"
			}
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_LAST:
#line 4415 "wizard.c"
			{
				gboolean _tmp21_ = FALSE;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				self->priv->skip_review_for_live = FALSE;
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp21_ = boxes_wizard_create (self);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (_tmp21_) {
#line 4424 "wizard.c"
					BoxesApp* _tmp22_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp22_ = boxes_app_app;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					boxes_ui_set_ui_state ((BoxesUI*) _tmp22_, BOXES_UI_STATE_COLLECTION);
#line 4430 "wizard.c"
				} else {
					BoxesApp* _tmp23_;
					BoxesNotificationbar* _tmp24_;
					const gchar* _tmp25_ = NULL;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp23_ = boxes_app_app;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp24_ = _tmp23_->notificationbar;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp25_ = _ ("Box creation failed");
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					boxes_notificationbar_display_error (_tmp24_, _tmp25_);
#line 4443 "wizard.c"
				}
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				return;
#line 4447 "wizard.c"
			}
			default:
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 4452 "wizard.c"
		}
	} else {
		BoxesWizardPage _tmp26_;
		BoxesWizardPage _tmp27_;
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp26_ = boxes_wizard_get_page (self);
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp27_ = _tmp26_;
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		switch (_tmp27_) {
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 4465 "wizard.c"
			{
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				boxes_wizard_destroy_machine (self);
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				break;
#line 4471 "wizard.c"
			}
			default:
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			break;
#line 4476 "wizard.c"
		}
	}
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp28_ = value;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp29_ = boxes_wizard_skip_page (self, _tmp28_);
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp29_) {
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return;
#line 4487 "wizard.c"
	}
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp30_ = value;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->_page = _tmp30_;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp31_ = self->priv->notebook;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp32_ = value;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_notebook_set_current_page (_tmp31_, (gint) _tmp32_);
#line 4499 "wizard.c"
	{
		gint i;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		i = 0;
#line 4504 "wizard.c"
		{
			gboolean _tmp33_;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			_tmp33_ = TRUE;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			while (TRUE) {
#line 4511 "wizard.c"
				gboolean _tmp34_;
				gint _tmp36_;
				GPtrArray* _tmp37_;
				gint _tmp38_;
				gint _tmp39_;
				GPtrArray* _tmp40_;
				gint _tmp41_;
				gconstpointer _tmp42_ = NULL;
				GtkLabel* _tmp43_;
				GtkLabel* label;
				GtkLabel* _tmp44_;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp34_ = _tmp33_;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (!_tmp34_) {
#line 4527 "wizard.c"
					gint _tmp35_;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					_tmp35_ = i;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					i = _tmp35_ + 1;
#line 4533 "wizard.c"
				}
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp33_ = FALSE;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp36_ = i;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp37_ = self->priv->steps;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp38_ = g_ptr_array_get_length (_tmp37_);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp39_ = _tmp38_;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				if (!(_tmp36_ < _tmp39_)) {
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
					break;
#line 4549 "wizard.c"
				}
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp40_ = self->priv->steps;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp41_ = i;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp42_ = g_ptr_array_index (_tmp40_, (guint) _tmp41_);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp43_ = _g_object_ref0 ((GtkLabel*) _tmp42_);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				label = _tmp43_;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp44_ = label;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				gtk_widget_modify_fg ((GtkWidget*) _tmp44_, GTK_STATE_NORMAL, NULL);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (label);
#line 4567 "wizard.c"
			}
		}
	}
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp45_ = self->priv->steps;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp46_ = boxes_wizard_get_page (self);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp47_ = _tmp46_;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp48_ = g_ptr_array_index (_tmp45_, (guint) _tmp47_);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_get_color ("white", &_tmp49_);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_modify_fg ((GtkWidget*) ((GtkLabel*) _tmp48_), GTK_STATE_NORMAL, &_tmp49_);
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp51_ = boxes_wizard_get_page (self);
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp52_ = _tmp51_;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp52_ != BOXES_WIZARD_PAGE_REVIEW) {
#line 4589 "wizard.c"
		const gchar* _tmp53_ = NULL;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp53_ = _ ("C_ontinue");
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp50_ = _tmp53_;
#line 4595 "wizard.c"
	} else {
		const gchar* _tmp54_ = NULL;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp54_ = _ ("C_reate");
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_tmp50_ = _tmp54_;
#line 4602 "wizard.c"
	}
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp55_ = self->priv->next_button;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp56_ = _tmp50_;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_button_set_label (_tmp55_, _tmp56_);
#line 4610 "wizard.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 4617 "wizard.c"
}


static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizard * self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp1_;
	BoxesMediaManager* _tmp2_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_parent_class);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = g_ptr_array_new_with_free_func (_g_object_unref0_);
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_ptr_array_unref0 (self->priv->steps);
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->steps = _tmp0_;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->steps;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_ptr_array_set_length (_tmp1_, (gint) BOXES_WIZARD_PAGE_LAST);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_media_manager_new ();
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->media_manager = _tmp2_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return obj;
#line 4652 "wizard.c"
}


static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_construct (GType object_type) {
	BoxesWizardWizardSummary * self = NULL;
	GtkTable* _tmp0_;
	GtkTable* _tmp1_;
	GtkTable* _tmp2_;
#line 607 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self = (BoxesWizardWizardSummary*) g_object_new (object_type, NULL);
#line 608 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = (GtkTable*) gtk_table_new ((guint) 1, (guint) 2, FALSE);
#line 608 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp0_);
#line 608 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->table);
#line 608 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->table = _tmp0_;
#line 609 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->table;
#line 609 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp1_, "row-spacing", (guint) 10, NULL);
#line 610 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->table;
#line 610 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp2_, "column-spacing", (guint) 20, NULL);
#line 612 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_summary_clear (self);
#line 607 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return self;
#line 4683 "wizard.c"
}


static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_new (void) {
#line 607 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return boxes_wizard_wizard_summary_construct (BOXES_WIZARD_TYPE_WIZARD_SUMMARY);
#line 4690 "wizard.c"
}


static void boxes_wizard_wizard_summary_add_property (BoxesWizardWizardSummary* self, const gchar* name, const gchar* value) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GtkLabel* _tmp2_;
	GtkLabel* label_name;
	GtkLabel* _tmp3_;
	GdkColor _tmp4_ = {0};
	GtkLabel* _tmp5_;
	GtkTable* _tmp6_;
	GtkLabel* _tmp7_;
	guint _tmp8_;
	guint _tmp9_;
	const gchar* _tmp10_;
	GtkLabel* _tmp11_;
	GtkLabel* label_value;
	GtkLabel* _tmp12_;
	GdkColor _tmp13_ = {0};
	GtkLabel* _tmp14_;
	GtkTable* _tmp15_;
	GtkLabel* _tmp16_;
	guint _tmp17_;
	guint _tmp18_;
	guint _tmp19_;
	GtkTable* _tmp20_;
#line 615 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 615 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (name != NULL);
#line 616 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 616 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	if (_tmp0_ == NULL) {
#line 617 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		return;
#line 4728 "wizard.c"
	}
#line 619 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = name;
#line 619 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new (_tmp1_);
#line 619 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp2_);
#line 619 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label_name = _tmp2_;
#line 620 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp3_ = label_name;
#line 620 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_get_color ("grey", &_tmp4_);
#line 620 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_modify_fg ((GtkWidget*) _tmp3_, GTK_STATE_NORMAL, &_tmp4_);
#line 621 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp5_ = label_name;
#line 621 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp5_, "xalign", 1.0f, NULL);
#line 622 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->table;
#line 622 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp7_ = label_name;
#line 622 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->current_row;
#line 622 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp9_ = self->priv->current_row;
#line 622 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_table_attach_defaults (_tmp6_, (GtkWidget*) _tmp7_, (guint) 0, (guint) 1, _tmp8_, _tmp9_ + 1);
#line 624 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp10_ = value;
#line 624 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp11_ = (GtkLabel*) gtk_label_new (_tmp10_);
#line 624 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp11_);
#line 624 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	label_value = _tmp11_;
#line 625 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp12_ = label_value;
#line 625 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_get_color ("white", &_tmp13_);
#line 625 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_modify_fg ((GtkWidget*) _tmp12_, GTK_STATE_NORMAL, &_tmp13_);
#line 626 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp14_ = label_value;
#line 626 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp14_, "xalign", 0.0f, NULL);
#line 627 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp15_ = self->priv->table;
#line 627 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp16_ = label_value;
#line 627 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp17_ = self->priv->current_row;
#line 627 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp18_ = self->priv->current_row;
#line 627 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_table_attach_defaults (_tmp15_, (GtkWidget*) _tmp16_, (guint) 1, (guint) 2, _tmp17_, _tmp18_ + 1);
#line 629 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp19_ = self->priv->current_row;
#line 629 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->current_row = _tmp19_ + 1;
#line 630 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp20_ = self->priv->table;
#line 630 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp20_);
#line 615 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_value);
#line 615 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_name);
#line 4798 "wizard.c"
}


static void boxes_wizard_wizard_summary_clear (BoxesWizardWizardSummary* self) {
	GtkTable* _tmp0_;
	GList* _tmp1_ = NULL;
	GtkTable* _tmp4_;
#line 633 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 634 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->table;
#line 634 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 4812 "wizard.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 634 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		child_collection = _tmp1_;
#line 634 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 4820 "wizard.c"
			GtkWidget* child = NULL;
#line 634 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
			child = (GtkWidget*) child_it->data;
#line 4824 "wizard.c"
			{
				GtkTable* _tmp2_;
				GtkWidget* _tmp3_;
#line 635 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp2_ = self->priv->table;
#line 635 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				_tmp3_ = child;
#line 635 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
				gtk_container_remove ((GtkContainer*) _tmp2_, _tmp3_);
#line 4834 "wizard.c"
			}
		}
#line 634 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		_g_list_free0 (child_collection);
#line 4839 "wizard.c"
	}
#line 638 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->table;
#line 638 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	gtk_table_resize (_tmp4_, (guint) 1, (guint) 2);
#line 639 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv->current_row = (guint) 0;
#line 4847 "wizard.c"
}


static GtkWidget* boxes_wizard_wizard_summary_get_widget (BoxesWizardWizardSummary* self) {
	GtkWidget* result;
	GtkTable* _tmp0_;
#line 603 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 603 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->table;
#line 603 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	result = (GtkWidget*) _tmp0_;
#line 603 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	return result;
#line 4862 "wizard.c"
}


static void boxes_wizard_wizard_summary_class_init (BoxesWizardWizardSummaryClass * klass) {
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_summary_parent_class = g_type_class_peek_parent (klass);
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardWizardSummaryPrivate));
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_wizard_summary_get_property;
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_wizard_summary_finalize;
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_WIZARD_SUMMARY_WIDGET, g_param_spec_object ("widget", "widget", "widget", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4877 "wizard.c"
}


static void boxes_wizard_wizard_summary_instance_init (BoxesWizardWizardSummary * self) {
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_WIZARD_SUMMARY_GET_PRIVATE (self);
#line 4884 "wizard.c"
}


static void boxes_wizard_wizard_summary_finalize (GObject* obj) {
	BoxesWizardWizardSummary * self;
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummary);
#line 604 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->table);
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_wizard_summary_parent_class)->finalize (obj);
#line 4896 "wizard.c"
}


static GType boxes_wizard_wizard_summary_get_type (void) {
	static volatile gsize boxes_wizard_wizard_summary_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_wizard_summary_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardWizardSummaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_wizard_summary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardWizardSummary), 0, (GInstanceInitFunc) boxes_wizard_wizard_summary_instance_init, NULL };
		GType boxes_wizard_wizard_summary_type_id;
		boxes_wizard_wizard_summary_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesWizardWizardSummary", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_wizard_summary_type_id__volatile, boxes_wizard_wizard_summary_type_id);
	}
	return boxes_wizard_wizard_summary_type_id__volatile;
}


static void _vala_boxes_wizard_wizard_summary_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardWizardSummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummary);
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_WIZARD_SUMMARY_WIDGET:
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_wizard_wizard_summary_get_widget (self));
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		break;
#line 4923 "wizard.c"
		default:
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 602 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		break;
#line 4929 "wizard.c"
	}
}


static void boxes_wizard_class_init (BoxesWizardClass * klass) {
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	boxes_wizard_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardPrivate));
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_wizard_real_ui_state_changed;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_wizard_real_get_actor;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_get_property;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_set_property;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_constructor;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_finalize;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4953 "wizard.c"
}


static void boxes_wizard_instance_init (BoxesWizard * self) {
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_GET_PRIVATE (self);
#line 4960 "wizard.c"
}


static void boxes_wizard_finalize (GObject* obj) {
	BoxesWizard * self;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_ptr_array_unref0 (self->priv->steps);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->notebook);
#line 19 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 21 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->next_button);
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->wizard_source);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->summary);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 25 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_progress);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->setup_vbox);
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_label);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->nokvm_label);
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->installer_image);
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->machine);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_parent_class)->finalize (obj);
#line 5004 "wizard.c"
}


GType boxes_wizard_get_type (void) {
	static volatile gsize boxes_wizard_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizard), 0, (GInstanceInitFunc) boxes_wizard_instance_init, NULL };
		GType boxes_wizard_type_id;
		boxes_wizard_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesWizard", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_type_id__volatile, boxes_wizard_type_id);
	}
	return boxes_wizard_type_id__volatile;
}


static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_ACTOR:
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		break;
#line 5031 "wizard.c"
		default:
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		break;
#line 5037 "wizard.c"
	}
}


static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 5047 "wizard.c"
		default:
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/wizard.vala"
		break;
#line 5053 "wizard.c"
	}
}



